﻿/****************************** Module Header ******************************\
Module Name:  Utilities
Project:      PwrSnsrLib
Copyright (c) 2019 WTG

Utility class for numeric formatting.


THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
\***************************************************************************/
using System;
using System.Collections.Generic;
using System.Linq;
using PowerMeterManagement;
using System.Text;

namespace PwrSnsrLib
{
    class Utilities
    {
        static string[] m_TimebaseLabels;
        public class SensorIOException : Exception
        {
            public SensorIOException(string message) : base(message)
            {
            }

            public SensorIOException(int err) : base(MapError(err))
            {
            }
        }
        public static string MapError(int err)
        {
            string retval = "Unknown error";
            m_errorMap.TryGetValue(err, out retval);
            return retval ?? "Unknown error";
        }

        static public  Dictionary<int, string> m_errorMap = new Dictionary<int, string>()
        {

            { (int)PwrSnsrErrorCodesEnum.IO_GENERAL, "I/O Error." },
            { (int)PwrSnsrErrorCodesEnum.IO_TIMEOUT,"Timeout." },
            { (int)PwrSnsrErrorCodesEnum.MODEL_NOT_SUPPORTED, "Sensor model not supported." },
            { (int)PwrSnsrErrorCodesEnum.INV_PARAMETER, "Invalid parameter." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_INVALID_SESSION_HANDLE, "Invalid session ID." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_STATUS_NOT_AVAILABLE, "Status not available." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_RESET_FAILED, "Reset failed." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_RESOURCE_UNKNOWN, "Unknown resource." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_ALREADY_INITIALIZED, "Session already initialized" },
            { (int)PwrSnsrErrorCodesEnum.ERROR_OUT_OF_MEMORY, "" },
            { (int)PwrSnsrErrorCodesEnum.ERROR_OPERATION_PENDING, "Operation pending." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_NULL_POINTER, "Null pointer error." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_UNEXPECTED_RESPONSE, "Unexpected response." },
            { (int)PwrSnsrErrorCodesEnum.ERROR_NOT_INITIALIZED, "Session not initialized." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_IO, "I/O error." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_INVALID_PARAM, "Invalid parameter" },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_ACCESS, "Access violation." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NO_DEVICE, "USB device lost." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NOT_FOUND, "USB device not found." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_BUSY, "USB busy." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_TIMEOUT, "Timeout error"},
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_OVERFLOW, "Overflow error." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_PIPE, "USB pipe error." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_INTERRUPTED, "Interrupted communication." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NO_MEM, "No memory available." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NOT_SUPPORTED, "Sensor not supported." },
            { (int)PwrSnsrErrorCodesEnum.LIBUSB_ERROR_OTHER, "Unknown error" },


        };

        public static string[] TimebaseLabels
        {
            get { return Utilities.m_TimebaseLabels; }
            private set { Utilities.m_TimebaseLabels = value; }
        }

        static double[] m_TimebaseMultipliers =
	    {				//	index
		    1.0e-9,	//	0
		    1.0e-9,	//	0
		    1.0e-9,	//	1
		    1.0e-9,	//	2
		    1.0e-9,	//	3
		    1.0e-9,	//	4
		    1.0e-9,	//	5
		    1.0e-6, 	//	6
		    1.0e-6, 	//	7
		    1.0e-6, 	//	8
		    1.0e-6, 	//	9
		    1.0e-6,	//	10
		    1.0e-6,	//	11
		    1.0e-6,	//	12
		    1.0e-6,	//	13
		    1.0e-6,	//	14
		    1.0e-3, 	//	15
		    1.0e-3, 	//	16
		    1.0e-3, 	//	17
		    1.0e-3, 	//	18
		    1.0e-3, 	//	19
		    1.0e-3,	//	20
		    1.0e-3, 	//	21
		    1.0e-3,	//	22
		    1.0e-3, 	//	23
		    1.0e0, 		//	24
		    1.0e0,  	//	25
		    1.0e0,  	//	26
		    1.0e0, 	//	27
		    1.0e0, 	//	28
		    1.0e0, 	//	29
		    1.0e0, 	//	30
		    1.0e0, 	//	31
		    1.0e0, 	//	32
		    1.0e0,	//	33
		    1.0e0 	//	34	
		
	    };
        static double[] m_TimeBases =
	    {				//	index
	        5.0e-9,	//	0
		    10.0e-9,	//	1
		    20.0e-9,	//	2
		    50.0e-9,	//	3
		    100.0e-9,	//	4
		    200.0e-9,	//	5
		    500.0e-9,	//	6
		    1.0e-6, 	//	7
		    2.0e-6, 	//	8
		    5.0e-6, 	//	9
		    10.0e-6, 	//	10
		    20.0e-6,	//	11
		    50.0e-6,	//	12
		    100.0e-6,	//	13
		    200.0e-6,	//	14
		    500.0e-6,	//	15
		    1.0e-3, 	//	16
		    2.0e-3, 	//	17
		    5.0e-3, 	//	18
		    10.0e-3, 	//	19
		    20.0e-3, 	//	20
		    50.0e-3,	//	21
		    100.0e-3, 	//	22
		    200.0e-3,	//	23
		    500.0e-3, 	//	24
		    1.0e0, 	//	25
		    2.0e0,  	//	26
		    5.0e0,  	//	27
		    10.0e0, 	//	28
		    30.0e0, 	//	29
		    60.0e0, 	//	30
		    120.0e0, 	//	31
		    300.0e0, 	//	32
		    600.0e0, 	//	33
		    1800.0e0,	//	34
		    3600.0e0 	//	35	
		
	    };

        static Dictionary<string, double> m_TimebaseTable = new Dictionary<string, double>();
        static Dictionary<string, double> m_TimebaseMultTable = new Dictionary<string, double>();
        static Utilities()
        {
            m_TimebaseLabels = new string[m_TimeBases.Length];
            for (int i = 0; i < m_TimeBases.Length; i++)
            {
                double val = m_TimeBases[i];
                if (val > 1.0)
                {
                    m_TimebaseLabels[i] = ToEngineeringNotation(val, "# ", 0) + "s/div";
                }
                else
                {
                    m_TimebaseLabels[i] = ToEngineeringNotation(val, "# ") + "s/div";
                }
                m_TimebaseTable.Add(m_TimebaseLabels[i], val);
                m_TimebaseMultTable.Add(m_TimebaseLabels[i], m_TimebaseMultipliers[i]);
            }

           



        }

        public static string GetLabelFromTimebase(double timebase)
        {
            var ret = m_TimebaseTable.Where(x => x.Value / timebase > 0.99 && x.Value / timebase < 1.01).Select(x => x.Key);
            if (ret.Count() > 0)
            {
                return ret.ElementAt(0);
            }
            return null;
        }
        public static void ThrowifError(int result)
        {
            if (result != PwrSnsrLib32.SUCCESS)
            {
                var msg = MapError(result);
                throw new SensorIOException(msg);
            }
        }
        public static string DecodeAscii(byte[] buffer)
        {
            int count = Array.IndexOf<byte>(buffer, 0, 0);
            if (count < 0) count = buffer.Length;
            return Encoding.ASCII.GetString(buffer, 0, count);
        }

        public static double GetTimebaseFromLabel(string label)
        {
            return m_TimebaseTable[label];
        }

        /// <summary>
        /// Converts a double to its Engineering format representation
        /// </summary>
        /// <param name="d">Double to convert.</param>
        /// <param name="numberFormat">Number format to use eg. "#.000"</param>
        /// <returns></returns>
        /// 
        static public string ToEngineeringNotation(double d, string numberFormat)
        {
            return  ToEngineeringNotation(d, numberFormat, 0,false);
        }

        static public string ToEngineeringNotation(double d, int significantDigits,int minExp = -9)
        {
            return ToEngineeringNotation(d, "", 0, false, true, significantDigits,minExp);
        }

        /// <summary>
        /// Converts a double to its Engineering format representation
        /// </summary>
        /// <param name="d">Double to convert.</param>
        /// <param name="numberFormat">Number format to use eg. "#.000"</param>
        /// <param name="exponent">Specified exponent units.</param>
        /// <returns></returns>
        /// 
        static public string ToEngineeringNotation(double d, string numberFormat,int exponent)
        {
            return ToEngineeringNotation(d, numberFormat, exponent, true);
        }


        static private string ToEngineeringNotation(double d, string numberFormat, int exponent, bool forceExponent, 
            bool useSigDigs = false, int sigDigs = 5, int minExp = -9)
        {
            //d = Math.Round(d, 12);
            if (!forceExponent)
            {
                exponent = (int)Math.Floor(Math.Log10(Math.Abs(d)));
            }

            
            if (exponent < minExp)
            {
                exponent = minExp;
            }

            double scaledVal = 0.0;
             
            if (exponent >=0)
            {
                switch (exponent)
                {
                    case 0:
                    case 1:
                    case 2:
                        scaledVal = d;
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " ";
                    case 3:
                    case 4:
                    case 5:
                        scaledVal = (d / 1e3);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " k";
                    case 6:
                    case 7:
                    case 8:
                        scaledVal = (d / 1e6);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " M";
                    case 9:
                    case 10:
                    case 11:
                        scaledVal = (d / 1e9);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " G";
                    case 12:
                    case 13:
                    case 14:
                        scaledVal = (d / 1e12);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " T";
                    case 15:
                    case 16:
                    case 17:
                        scaledVal = (d / 1e15);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " P";
                    case 18:
                    case 19:
                    case 20:
                        scaledVal = (d / 1e18);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " E";
                    case 21:
                    case 22:
                    case 23:
                        scaledVal = (d / 1e21);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " Z";
                    default:
                        scaledVal = (d / 1e24);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " Y";
                }
            }
            else if (exponent < 0)
            {
                switch (exponent)
                {
                    case 0:
                        scaledVal = d;
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " ";
                    case -1:
                    case -2:
                    case -3:
                        scaledVal = (d * 1e3);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " m";
                    case -4:
                    case -5:
                    case -6:
                        scaledVal = (d * 1e6);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " μ";
                    case -7:
                    case -8:
                    case -9:
                        scaledVal =(d * 1e9);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " n";
                    case -10:
                    case -11:
                    case -12:
                        scaledVal = (d * 1e12);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " p";
                    case -13:
                    case -14:
                    case -15:
                        scaledVal = (d * 1e15);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " f";
                    case -16:
                    case -17:
                    case -18:
                        scaledVal = (d * 1e15);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " a";
                    case -19:
                    case -20:
                    case -21:
                        scaledVal = (d * 1e15);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " z";
                    default:
                        scaledVal = (d * 1e15);
                        if (useSigDigs)
                        {
                            numberFormat = GetSigDigFormat(scaledVal, sigDigs);
                        }
                        return scaledVal.ToString(numberFormat) + " y";
                }
            }
            else
            {
                if (useSigDigs)
                {
                    numberFormat = GetSigDigFormat(d, sigDigs);
                }
                return d.ToString(numberFormat) + " ";
            }
        }
        static string GetSigDigFormat(double number, int numberDigits)
        {
            int exponent = 0;
            if (number != 0.0)
            {

                exponent = (int)Math.Floor(Math.Log10(Math.Abs(number)));
            }
            string format = "#0";
            int rightPlaces = numberDigits - exponent - 1;

            for (int i = 0; i < rightPlaces; i++)
            {
                if (i == 0)
                {
                    format += ".0";
                }
                else
                {
                    format += "0";
                }
            }
            return format;
        }

    
    }
}
