﻿/****************************** Module Header ******************************\
Module Name:  MainForm
Project:      RTPMeasureBuffDemo
Copyright (c) 2019 WTG

Windows form illustrating the use of measurement buffer.


THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
\***************************************************************************/
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PowerMeterManagement;
using PwrSnsrLib;

namespace RTPMeasureBuffDemo
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
            FindResources();
            setupMbufControls();
            MeterHandle = 0;
        }

        int MeterHandle { set; get; }
        bool MeterOpen { set; get; }

        private void setupMbufControls()
        {
            cBoxMBstart.SelectedIndex = 0;
            cBoxMBgate.SelectedIndex = 0;
        }

        void FindResources()
        {
            try
            {
                //Clear current list.
                chkedLstBxChans.Items.Clear();
                //Find resources and build a pipe-delimited string.
                int buffSize = 256;
                byte[] buff = new byte[buffSize];
                int err = PwrSnsrLib32.PwrSnsr_FindResources("|", buffSize, buff);
                Utilities.ThrowifError(err);
                var s = Utilities.DecodeAscii(buff);
                //Check if string is valid.
                if (!string.IsNullOrWhiteSpace(s))
                {
                    //Split string into array.
                    var resources = s.Split('|');
                    //Loop throught the results and add them to the combobox
                    foreach (string resource in resources)
                        chkedLstBxChans.Items.Add(resource);
                }

                //Select first item if combobox is not empty.
                if (chkedLstBxChans.Items.Count > 0)
                {
                    chkedLstBxChans.SelectedIndex = 0;
                    btnConnect.Text = "Connect Sensor";
                }
                else
                {
                    btnConnect.Text = "Find Sensors";
                }
            }

            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Find Resources Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnConnect_Click(object sender, EventArgs e)
        {
            string s, rsrcString = null;
            try
            {
                switch (btnConnect.Text)
                {
                    case "Connect Sensor":
                        cBoxChan.Items.Clear();
                        cBoxTrigChan.Items.Clear();
                        foreach (int indexChecked in chkedLstBxChans.CheckedIndices)
                        {
                            s = chkedLstBxChans.Items[indexChecked].ToString();
                            string[] ParseStr = s.Split(new string[] { "::" }, StringSplitOptions.None);
                            cBoxChan.Items.Add(ParseStr[3]);
                            cBoxTrigChan.Items.Add(ParseStr[3]);
                            if (chkedLstBxChans.CheckedIndices.Count == 1)
                                rsrcString = s;

                            else if (indexChecked < chkedLstBxChans.CheckedIndices.Count - 1)
                                s = s + "; ";
                            rsrcString = rsrcString + s;

                        }
                        cBoxTrigChan.Items.Add("Independent");
                        cBoxTrigChan.SelectedIndex = 0;
                        cBoxChan.SelectedIndex = 0;

                        OpenMeter(rsrcString);
                        tabControl1.SelectTab(1);
                        for (int i = 0; i < numMeters; i++)
                        {
                            tabCtlData.TabPages[i].Text = sensInfo[i].serNum;
                        }

                        break;
                    case "Find Sensors":
                        FindResources();
                        break;
                    case "Disconnect":
                        btnConnect.Text = "Find Sensors";
                        break;
                    default:
                        break;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Connect/Disconnect Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        List<float>[] m_minVals;
        List<float>[] m_avgVals;
        List<float>[] m_maxVals;

        List<double>[] m_startVals;
        List<float>[] m_durVals;
        List<uint>[] m_seqVals;

        int numMeters;
        public struct sensData
        {
            public string model;
            public string serNum;
            public string frmRev;
        }
        public sensData[] sensInfo;
        /// <summary>
        /// Opens a session to a virtual power meter
        /// </summary>
        void OpenMeter(string resources)
        {

            try
            {
                numMeters = cBoxChan.Items.Count;
                sensInfo = new sensData[numMeters];

                MeterOpen = false;
                //Initilize driver using the resource name in combobox1.            
                int handle = 0;
                var ret = PwrSnsrLib32.PwrSnsr_init(resources, ref handle);
                Utilities.ThrowifError(ret);
                //Set to defaults
                ret = PwrSnsrLib32.PwrSnsr_reset(handle);
                Utilities.ThrowifError(ret);

                MeterHandle = handle;
                MeterOpen = true;
                if (numMeters > 1)
                {
                    PwrSnsrTriggerSourceEnum trenum = PwrSnsrTriggerSourceEnum.TriggerSourceIndependent;
                    ret = PwrSnsrLib32.PwrSnsr_SetTrigSource(MeterHandle, trenum);
                    Utilities.ThrowifError(ret);
                }
                //Set for continuous run mode.
                ret = PwrSnsrLib32.PwrSnsr_SetInitiateContinuous(MeterHandle, 1);
                Utilities.ThrowifError(ret);

                m_maxVals = new List<float>[numMeters];
                m_minVals = new List<float>[numMeters];
                m_avgVals = new List<float>[numMeters];
                m_durVals = new List<float>[numMeters];

                m_startVals = new List<double>[numMeters];
                m_seqVals = new List<uint>[numMeters];

                for (int i = 0; i < numMeters; i++)
                {
                    //Define the channel string
                    string chan = "CH" + (i + 1);

                    m_maxVals[i] = new List<float>();
                    m_minVals[i] = new List<float>();
                    m_avgVals[i] = new List<float>();
                    m_durVals[i] = new List<float>();
                    m_startVals[i] = new List<double>();
                    m_seqVals[i] = new List<uint>();

                    byte[] tmp = new byte[20];
                    //Get the model
                    ret = PwrSnsrLib32.PwrSnsr_GetModel(MeterHandle, chan, 16, tmp);
                    Utilities.ThrowifError(ret);
                    sensInfo[i].model = Utilities.DecodeAscii(tmp);
                    //Get serial number
                    ret = PwrSnsrLib32.PwrSnsr_GetSerialNumber(MeterHandle, chan, 16, tmp);
                    Utilities.ThrowifError(ret);
                    sensInfo[i].serNum = Utilities.DecodeAscii(tmp);
                    //Get firmware revision
                    ret = PwrSnsrLib32.PwrSnsr_GetFirmwareVersion(MeterHandle, chan, 20, tmp);
                    Utilities.ThrowifError(ret);
                    sensInfo[i].frmRev = Utilities.DecodeAscii(tmp);
                }

                txtbxModelNo.Text = sensInfo[0].model;
                txtbxSerialNo.Text = sensInfo[0].serNum;
                tBoxFirmRev.Text = sensInfo[0].frmRev;


                //Get the maximum timebase allowed on this meter.
                float max = 0.0f;
                ret = PwrSnsrLib32.PwrSnsr_GetMaxTimebase(MeterHandle, ref max);
                Utilities.ThrowifError(ret);
                //Construct max label.
                string maxLabel = Utilities.GetLabelFromTimebase(max);
                //Find the index of the max timebase
                int index = Array.IndexOf(Utilities.TimebaseLabels, maxLabel);
                //Clear the old values, if any.
                //Add the relevant timebase labels.
                //Get the current timebase and label.
                float timebase = 0.0f;
                ret = PwrSnsrLib32.PwrSnsr_GetTimebase(MeterHandle, ref timebase);
                Utilities.ThrowifError(ret);
                string currentTimebase = Utilities.GetLabelFromTimebase(timebase);
                //Set the selected item to the current timebase.
                setGateMode();
                setStartMode();
                btnConnect.Text = "Disconnect";
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Find Resources Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void setGateMode()
        {
            int ret;
            try
            {
                string val = cBoxMBgate.Items[cBoxMBgate.SelectedIndex].ToString().ToLower();
                if (val.Contains("burst"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGateBurst);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("external trig"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGateExtTrig);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("external gate"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGateExtGate);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("marker"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGateMarker);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("period"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGatePeriodic);
                    Utilities.ThrowifError(ret);
                }


            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Set Buffered Gate Mode Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void setStartMode()
        {
            int ret;
            try
            {

                string val = cBoxMBstart.Items[cBoxMBstart.SelectedIndex].ToString().ToLower();
                if (val.Contains("external enable"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetStartMode(MeterHandle, PwrSnsrMeasBuffStartModeEnum.MeasBuffStartModeExternalEnable);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("external start"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetStartMode(MeterHandle, PwrSnsrMeasBuffStartModeEnum.MeasBuffStartModeExternalStart);
                    Utilities.ThrowifError(ret);
                }
                else if (val.Contains("immediate"))
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetStartMode(MeterHandle, PwrSnsrMeasBuffStartModeEnum.MeasBuffStartModeImmediate);
                    Utilities.ThrowifError(ret);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Set Buffered Start Mode Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }


        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void cBoxMBstart_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (MeterHandle == 0) return;
            if (cBoxMBstart.SelectedIndex < 0) return;
            setStartMode();

        }

        private void cBoxMBgate_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (MeterHandle == 0) return;
            if (cBoxMBgate.SelectedIndex < 0) return;
            setGateMode();
        }

        int numSamples;
        void GetArrays()
        {


            int rtnCnt = 0;
            int siz = Convert.ToInt32(tBoxStopCnt.Text);


            for (int i = 0; i < numMeters; i++)
            {
                m_avgVals[i].Clear();
                m_minVals[i].Clear();
                m_maxVals[i].Clear();
                m_startVals[i].Clear();
                m_durVals[i].Clear();
                m_seqVals[i].Clear();
            }

            float[] zeros = new float[numSamples];
            double[] zeros2 = new double[numSamples];
            var minVals = new float[siz];
            var avgVals = new float[siz];
            var maxVals = new float[siz];
            var durVals = new float[siz];
            var seqVals = new uint[siz];
            var strtVals = new double[siz];
            for (int i = 0; i < numMeters; i++)
            {
                string ch = "CH" + (i + 1);
                int ret = PwrSnsrLib32.PwrSnsr_GetBufferedAverageMeasurements(MeterHandle, ch, siz, avgVals, ref rtnCnt);
                Utilities.ThrowifError(ret);
                m_avgVals[i] = avgVals.ToList();

                if (cbxMBmin.Checked)
                {
                    ret = PwrSnsrLib32.PwrSnsr_GetMinMeasurements(MeterHandle, ch, siz, minVals, ref rtnCnt);
                    Utilities.ThrowifError(ret);
                    m_minVals[i] = minVals.ToList();
                }
                else
                    m_minVals[i].AddRange(zeros);

                if (cbxMBmax.Checked)
                {
                    ret = PwrSnsrLib32.PwrSnsr_GetMaxMeasurements(MeterHandle, ch, siz, maxVals, ref rtnCnt);
                    Utilities.ThrowifError(ret);
                    m_maxVals[i] = maxVals.ToList();
                }
                else
                    m_maxVals[i].AddRange(zeros);
                if (cbxMBstrt.Checked)
                {
                    ret = PwrSnsrLib32.PwrSnsr_GetStartTimes(MeterHandle, ch, siz, strtVals, ref rtnCnt);
                    Utilities.ThrowifError(ret);
                    m_startVals[i] = strtVals.ToList();
                }
                else
                {
                    m_startVals[i].AddRange(zeros2);
                }

                ret = PwrSnsrLib32.PwrSnsr_GetDurations(MeterHandle, ch, siz, durVals, ref rtnCnt);
                Utilities.ThrowifError(ret);
                m_durVals[i] = durVals.ToList();

                ret = PwrSnsrLib32.PwrSnsr_GetSequenceNumbers(MeterHandle, ch, siz, seqVals, ref rtnCnt);
                Utilities.ThrowifError(ret);
                m_seqVals[i] = seqVals.ToList();

            }

        }
        int startIdx = 0, endIdx = 0, lines = 0;
        private void listResults()
        {
            m_data_cache.Clear();
            startIdx = Convert.ToInt32(tBxStrtIdx.Text);
            endIdx = Convert.ToInt32(tBxEndIdx.Text);
            if (rdoCount.Checked)
            {
                startIdx = 0;
                lines = endIdx;
            }
            else
            {
                lines = endIdx - startIdx;
            }
            var views = new ListView[] { listView1, listView2, listView3, listView4 };
            int i = 0;
            foreach (var view in views)
            {
                view.VirtualListSize = 0;
                if (i < numMeters)
                {
                    view.VirtualListSize = lines;
                }
                i++;
            }
        }

        private void mbuffToClipboard()
        {
            StringBuilder sb = new StringBuilder();
            Clipboard.Clear();
            int lcount;
            lcount = Convert.ToInt32(tBoxStopCnt.Text); 
            int k = tabCtlData.SelectedIndex; 
            sb.Append(string.Format("{0:S}\t{1:S}\t{2:S}\t{3:S}\t{4:S}\r\n", "Start", "End", "Start", "End", sensInfo[k].serNum));
            sb.Append(string.Format("{0:S}\t{1:S}\t{2:S}\t{3:S}\t{4:S}\t{5:S}\r\n", "Delay", "Delay", "Qual", "Qual", "Duration", "Period"));
            sb.Append(string.Format("{0:S}\t{1:S}\t{2:S}\t{3:S}\t{4:S}\t{5:S}\r\n\r\n", tBoxGtStDly.Text, tBoxGtEndDly.Text, tBoxGtStrtQual.Text, tBoxGtEndQual.Text, tBoxGtDurat.Text, tBoxGtPeriod.Text));
            sb.Append(string.Format("{0:S}\t{1:S}\t{2:S}\t{3:S}\t{4:S}\t{5:S}\t{6:S}\r\n", "idx", "count", "durat", "start time", "min pwr", "avg pwr", "max pwr"));
            for (int i = 0; i < lcount; i++)
            {
                sb.Append(string.Format("{0:D}\t{1:D}\t{2:G}\t{3:G}\t{4:G}\t{5:G}\t{6:G}\r\n", i, m_seqVals[k][i], m_durVals[k][i], m_startVals[k][i], m_minVals[k][i], m_avgVals[k][i], m_maxVals[k][i]));

            }
            Clipboard.SetText(sb.ToString());
        }

        private void btnAcquireMeasBuff_Click(object sender, EventArgs e)
        {
            if (MeterHandle == 0) return;
            Cursor = Cursors.WaitCursor;
            tBoxStat.Text = "Acquiring...";
            numSamples = Convert.ToInt32(tBoxStopCnt.Text);
            var views = new ListView[] { listView1, listView2, listView3, listView4 };
            m_data_cache.Clear();
            Update();
            foreach (var view in views)
            {
                view.VirtualListSize = 0;
            }           
            tBxEndIdx.Text = numSamples.ToString();
            try
            {
                AcquireMeasBuff();
                if (!aborted)
                {
                    GetArrays();
                    listResults();
                }


            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Acquire Measure Buffered Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            Cursor = Cursors.Default;
        }

        bool aborted;
        void AcquireMeasBuff()
        {
            aborted = false;
            float period, pulseWid;
            float strtQal = 0, endQal = 0, strtDly = 0, endDly = 0;
            PwrSnsrMeasBuffStopReasonEnum StopReason = PwrSnsrMeasBuffStopReasonEnum.MeasBuffStopReasonNone;
            int ret, rtnCnt = 0;

            try
            {
                for (int i = 0; i < numMeters; i++)
                {
                    ret = PwrSnsrLib32.PwrSnsr_SetCapture(MeterHandle, "CH" + (i + 1), 0);
                }

                if (cBoxMBgate.SelectedItem.ToString().ToLower().Contains("periodic"))
                {
                    pulseWid = Convert.ToSingle(tBoxGtDurat.Text);
                    period = Convert.ToSingle(tBoxGtPeriod.Text);
                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGatePeriodic);
                    Utilities.ThrowifError(ret);
                    ret = PwrSnsrLib32.PwrSnsr_SetDuration(MeterHandle, pulseWid);
                    Utilities.ThrowifError(ret);
                    ret = PwrSnsrLib32.PwrSnsr_SetPeriod(MeterHandle, period);
                    Utilities.ThrowifError(ret);
                }
                strtQal = Convert.ToSingle(tBoxGtStrtQual.Text);
                endQal = Convert.ToSingle(tBoxGtEndQual.Text);
                strtDly = Convert.ToSingle(tBoxGtStDly.Text);
                endDly = Convert.ToSingle(tBoxGtEndDly.Text);

                ret = PwrSnsrLib32.PwrSnsr_SetStartQual(MeterHandle, strtQal);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetEndQual(MeterHandle, endQal);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetStartDelay(MeterHandle, strtDly);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetEndDelay(MeterHandle, endDly);
                Utilities.ThrowifError(ret);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Values not in numeric format", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }


            int idx = cBoxTrigChan.SelectedIndex;
            PwrSnsrTriggerSourceEnum trenum = PwrSnsrTriggerSourceEnum.TriggerSourceIndependent;
           
            if (!cBoxTrigChan.SelectedItem.ToString().Contains("Indep"))
            {
                switch (idx)
                {
                    case 0:
                        trenum = PwrSnsrTriggerSourceEnum.TriggerSourceChannel1;
                        break;
                    case 1:
                        trenum = PwrSnsrTriggerSourceEnum.TriggerSourceChannel2;
                        break;
                    case 2:
                        trenum = PwrSnsrTriggerSourceEnum.TriggerSourceChannel3;
                        break;
                    case 3:
                        trenum = PwrSnsrTriggerSourceEnum.TriggerSourceChannel4;
                        break;
                }
            }
            
            double timeOut = 0.0;  // in seconds
            if (double.TryParse(tBoxStopTime.Text, out timeOut))
            {
                if (timeOut == 0.0)
                {
                    timeOut = 5.0;
                }
            }
            else
            {
                timeOut = 5.0;
            }
            ret = PwrSnsrLib32.PwrSnsr_SetTrigSource(MeterHandle, trenum);
            PwrSnsrTriggerModeEnum trMode = PwrSnsrTriggerModeEnum.TriggerModeNormal;
            ret = PwrSnsrLib32.PwrSnsr_SetTrigMode(MeterHandle, trMode);
            float tLev = Convert.ToSingle(tBxTrgLev.Text);
            ret = PwrSnsrLib32.PwrSnsr_SetTrigLevel(MeterHandle, tLev);
            Utilities.ThrowifError(ret);

            ret = PwrSnsrLib32.PwrSnsr_AcquireMeasurements(MeterHandle, timeOut, Convert.ToInt32(tBoxStopCnt.Text), ref StopReason, ref rtnCnt);
            Utilities.ThrowifError(ret);

            tBoxStat.Text = StopReason.ToString().Substring(18, StopReason.ToString().Length - 18);

            if (tBoxStat.Text.Contains("verran") || tBoxStat.Text.Contains("edOut"))
            {
                aborted = true;
            }
        }

        private void btnUpdLV_Click(object sender, EventArgs e)
        {
            listResults();
        }

        private void btn2Clip_Click(object sender, EventArgs e)
        {
            mbuffToClipboard();
        }

        private void cBoxChan_DropDownClosed(object sender, EventArgs e)
        {
            int j = cBoxChan.SelectedIndex;
            txtbxModelNo.Text = sensInfo[j].model;
            txtbxSerialNo.Text = sensInfo[j].serNum;
            tBoxFirmRev.Text = sensInfo[j].frmRev;
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            int ret = PwrSnsrLib32.PwrSnsr_reset(MeterHandle);
            Utilities.ThrowifError(ret);
            ret = PwrSnsrLib32.PwrSnsr_SetInitiateContinuous(MeterHandle, 1);
            Utilities.ThrowifError(ret);
            setGateMode();
            setStartMode();

        }      

        private void listView1_RetrieveVirtualItem(object sender, RetrieveVirtualItemEventArgs e)
        {
            try
            {
                var lvi = RetrieveVirtualItem(listView1, 0, e);
                e.Item = lvi;

            }
            catch
            {
                e.Item = null;
            }
        }
        Dictionary<int[], ListViewItem> m_data_cache = new Dictionary<int[], ListViewItem>();
        ListViewItem RetrieveVirtualItem(ListView lv, int tableIndex, RetrieveVirtualItemEventArgs e)
        {
            var index = e.ItemIndex + startIdx;
            ListViewItem retval = null;
            var key = new int[] { tableIndex, index };
            if (m_data_cache.TryGetValue(key, out retval))
            {
                return retval;
            }
            if (m_seqVals[tableIndex].Count > index - 1)
            {
                var min = cbxMBmin.Checked ? m_minVals[tableIndex][index].ToString() : "";
                var max = cbxMBmax.Checked ? m_maxVals[tableIndex][index].ToString() : "";
                var items = new string[]
                {
                    m_seqVals[tableIndex][index].ToString(),
                    m_durVals[tableIndex][index].ToString(),
                    m_startVals[tableIndex][index].ToString(),
                    min,
                    m_avgVals[tableIndex][index].ToString(),
                    max

                };
                retval = new ListViewItem(items);
                m_data_cache.Add(key, retval);
            }

            return retval;
        }

        private void listView2_RetrieveVirtualItem(object sender, RetrieveVirtualItemEventArgs e)
        {
            try
            {
                var lvi = RetrieveVirtualItem(listView2, 1, e);
                e.Item = lvi;

            }
            catch
            {
                e.Item = null;
            }
        }

        private void listView3_RetrieveVirtualItem(object sender, RetrieveVirtualItemEventArgs e)
        {
            try
            {
                var lvi = RetrieveVirtualItem(listView3, 2, e);
                e.Item = lvi;

            }
            catch
            {
                e.Item = null;
            }
        }

        private void listView4_RetrieveVirtualItem(object sender, RetrieveVirtualItemEventArgs e)
        {
            try
            {
                var lvi = RetrieveVirtualItem(listView4, 1, e);
                e.Item = lvi;

            }
            catch
            {
                e.Item = null;
            }
        }
    }
}
