﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization;
using PowerMeterManagement;
using PwrSnsrLib;
using System.Threading;
using System.Windows.Forms.DataVisualization.Charting;
using MSExcel = Microsoft.Office.Interop.Excel;
using System.Runtime.InteropServices;



namespace RTPmultiMBuffDemo
{
    public partial class MainForm1 : Form
    {
        public enum TRIGSRC_ENUM
        { /* values for TrigSource */
            TRINT,      /* 0: internal trigger source */
            TREXT,      /* 1: external trigger source */
            TRMASTER,   /* 2: internal trigger as master */
            TRSLAVE,    /* 3: slave trigger (from another channel) */
                        //TRLOGIC,	/* 4: trigger from FPGA logic (filtered ADC code) */
                        //TRSTATIC,	/* 5: trigger static (rising: true, falling: false) */
                        //TRPULSED	/* 6: trigger pulsing for test */
        }
        public enum TRIGMODE_ENUM
        {
            TRPK2PK,    /* 0: pk-to-pk auto trigger mode */
            TRAUTO,     /* 1: auto trigger mode */
            TRNORM,     /* 2: norm trigger mode */
            TRFREE      /* 3: free-run trigger mode */
        }

        public MainForm1()
        {
            InitializeComponent();

            //setupTrigSrcs();
            setupMbufControls();
            chartMeasBuff.ChartAreas[0].AxisX.MajorGrid.LineColor = Color.Gray;   //ForestGreen;
            chartMeasBuff.ChartAreas[0].AxisY.MajorGrid.LineColor = Color.Gray;   //ForestGreen;
            chartMeasBuff.ChartAreas[0].BackColor = Color.Black;

        }
        int MeterHandle { set; get; }
        bool MeterOpen { set; get; }
        void FindResources()
        {
            //Clear current list.
            cboAvResources.Items.Clear();
            //Find resources and build a pip-delimited string.
            int buffSize = 256;
            byte[] buff = new byte[buffSize];
            int err = PwrSnsrLib32.PwrSnsr_FindResources("|", buffSize, buff);
            Utilities.ThrowifError(err);
            var s = Utilities.DecodeAscii(buff);
            //Check if string is valid.
            if (!string.IsNullOrWhiteSpace(s))
            {
                //Split string into array.
                var resources = s.Split('|');
                //Loop throught the results and add them to the combobox
                foreach (string resource in resources)
                {
                    cboAvResources.Items.Add(resource);
                    //cBox1.Items.Add(resource);
                }
            }

            //Select first item if combobox is not empty.
            if (cboAvResources.Items.Count > 0)
            {
                cboAvResources.SelectedIndex = 0;
            }

        }

        private void btnConnect_Click(object sender, EventArgs e)
        {
            try
            {
                switch (btnConnect.Text)
                {
                    case "Connect Sensor":
                        OpenSensor();
                        if (btnConnect.Text.Contains("Disconnect"))
                        {
                            //tabControl1.SelectTab("Mbuf Controls");
                            tabControl1.SelectTab("tpMBcontrols");
                            btnAcquireMeasBuff.Enabled = true;
                            btnSaveExeFile.Enabled = true;
                            btnExit.Enabled = true;
                            cBoxAvgs.SelectedIndex = 0;
                            setupTrigSrcs();
                        }
                        break;
                    case "Find Sensors":
                        FindResources();
                        btnConnect.Text = "Connect Sensor";
                        break;
                    case "Disconnect":
                        btnConnect.Text = "Find Sensors";
                        ////m_meter.Close();
                        ////m_meter = null;
                        break;
                    default:
                        break;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Connect/Disconnect Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        void OpenSensor()
        {
            MeterOpen = false;
            //Initilize driver using the resource name in combobox1.            
            int handle = 0;
            var ret = PwrSnsrLib32.PwrSnsr_init(cboAvResources.Text, ref handle);
            Utilities.ThrowifError(ret);
            //Set to defaults
            ret = PwrSnsrLib32.PwrSnsr_reset(handle);
            Utilities.ThrowifError(ret);

            MeterHandle = handle;
            MeterOpen = true;

            //Set for continuous run mode.
            ret = PwrSnsrLib32.PwrSnsr_SetInitiateContinuous(MeterHandle, 1);
            Utilities.ThrowifError(ret);

            //Get the maximum timebase allowed on this sensor.
            float max = 0.0f;
            ret = PwrSnsrLib32.PwrSnsr_GetMaxTimebase(MeterHandle, ref max);
            Utilities.ThrowifError(ret);
            //Construct max label.
            string maxLabel = Utilities.GetLabelFromTimebase(max);
            //Find the index of the max timebase
            int index = Array.IndexOf(Utilities.TimebaseLabels, maxLabel);
            //Clear the old values, if any.
            cboxTimeBase.Items.Clear();
            //Add the relevant timebase labels.
            for (int i = 0; i <= index; i++)
            {
                cboxTimeBase.Items.Add(Utilities.TimebaseLabels[i]);
            }
            //Get the current timebase and label.
            float timebase = 0.0f;
            ret = PwrSnsrLib32.PwrSnsr_GetTimebase(MeterHandle, ref timebase);
            Utilities.ThrowifError(ret);
            string currentTimebase = Utilities.GetLabelFromTimebase(timebase);
            //Set the selected item to the current timebase.
            cboxTimeBase.SelectedItem = currentTimebase;
            //Set the bandwitch button state.
            PwrSnsrBandwidthEnum bw = PwrSnsrBandwidthEnum.BandwidthHigh;
            ret = PwrSnsrLib32.PwrSnsr_GetBandwidth(MeterHandle, "CH1", ref bw);
            Utilities.ThrowifError(ret);
            //            checkBox2.Checked = (bw == PwrSnsrBandwidthEnum.BandwidthLow);
            //Set averaging to 8 vis comboBox3
            cBoxAvgs.SelectedIndex = 3;
            byte[] model = new byte[16];
            byte[] sNum = new byte[16];
            byte[] frmRev = new byte[20];
            ret = PwrSnsrLib32.PwrSnsr_GetModel(MeterHandle, "CH1", 16, model);
            Utilities.ThrowifError(ret);
            ret = PwrSnsrLib32.PwrSnsr_GetSerialNumber(MeterHandle, "CH1", 16, sNum);
            Utilities.ThrowifError(ret);
            ret = PwrSnsrLib32.PwrSnsr_GetFirmwareVersion(MeterHandle, "CH1", 20, frmRev);

            txtbxModelNo.Text = Utilities.DecodeAscii(model);
            txtbxSerialNo.Text = Utilities.DecodeAscii(sNum);
            tBoxFirmRev.Text = Utilities.DecodeAscii(frmRev);
            btnConnect.Text = "Disconnect";
        }

        void AcquireMeasBuff()
        {
            float period, pulseWid;
            //           bool timedout = true;
            float strtQal = 0, endQal = 0, strtDly = 0, endDly = 0;

            tBoxStat.Text = "";
            Update();
            PwrSnsrMeasBuffStopReasonEnum StopReason = PwrSnsrMeasBuffStopReasonEnum.MeasBuffStopReasonNone;
            int ret,rtnCnt = 0;
            try
            {
                if (cBoxMBgate.SelectedItem.ToString().ToLower().Contains("periodic"))
                {
                    pulseWid = Convert.ToSingle(tBoxGtDurat.Text);
                    period = Convert.ToSingle(tBoxGtPeriod.Text);
                    // ret = PwrSnsrLib32.PwrSnsr_SetMeasBuffEnabled(MeterHandle, 1); 

                    ret = PwrSnsrLib32.PwrSnsr_SetGateMode(MeterHandle, PwrSnsrMeasBuffGateEnum.MeasBuffGatePeriodic);
                    Utilities.ThrowifError(ret);
                    ret = PwrSnsrLib32.PwrSnsr_SetDuration(MeterHandle, pulseWid);
                    Utilities.ThrowifError(ret);
                    ret = PwrSnsrLib32.PwrSnsr_SetPeriod(MeterHandle, period);
                    Utilities.ThrowifError(ret);
                }
                strtQal = Convert.ToSingle(tBoxGtStrtQual.Text);
                endQal = Convert.ToSingle(tBoxGtEndQual.Text);
                strtDly = Convert.ToSingle(tBoxGtStDly.Text);
                endDly = Convert.ToSingle(tBoxGtEndDly.Text);

                ret = PwrSnsrLib32.PwrSnsr_SetStartQual(MeterHandle, strtQal);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetEndQual(MeterHandle, endQal);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetStartDelay(MeterHandle, strtDly);
                Utilities.ThrowifError(ret);
                ret = PwrSnsrLib32.PwrSnsr_SetEndDelay(MeterHandle,endDly);
                Utilities.ThrowifError(ret);


            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Values not in numeric format", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            ret = PwrSnsrLib32.PwrSnsr_AcquireMeasurements(MeterHandle, 20, Convert.ToInt32(tBoxStopCnt.Text), ref StopReason, ref rtnCnt);
            Utilities.ThrowifError(ret);

            // lstVals.Items.Add(StopReason);
            tBoxStat.Text = StopReason.ToString();
        }

        List<float> m_minVals = new List<float>();
        List<float> m_avgVals = new List<float>();
        List<float> m_maxVals = new List<float>();

        List<double> m_startVals = new List<double>();
        List<float> m_durVals = new List<float>();
        List<int> m_seqVals = new List<int>();

        List<float> limit_maxVals = new List<float>();
        List<float> limit_minVals = new List<float>();


        void GetArrays()
        {
            float[] minVals;
            float[] avgVals;
            float[] maxVals;
            float[] durVals;
            int[] seqVals;
            double[] strtVals;

            m_avgVals.Clear();
            m_minVals.Clear();
            m_maxVals.Clear();
            m_startVals.Clear();
            m_durVals.Clear();
            m_seqVals.Clear();
            int rtnCnt = 0;
            int siz = Convert.ToInt32(tBoxStopCnt.Text);
            minVals = new float[siz];
            avgVals = new float[siz];
            maxVals = new float[siz];
            durVals = new float[siz];
            seqVals = new int[siz];
            strtVals = new double[siz];


            //var meas = m_meter.Channels.MeasurementBuffer.Measurements;

            int ret = PwrSnsrLib32.PwrSnsr_GetBufferedAverageMeasurements(MeterHandle, "CH1", siz, avgVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_avgVals.AddRange(avgVals);

            ret = PwrSnsrLib32.PwrSnsr_GetMinMeasurements(MeterHandle, "CH1", siz, minVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_minVals.AddRange(minVals);

            ret = PwrSnsrLib32.PwrSnsr_GetMaxMeasurements(MeterHandle, "CH1", siz, maxVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_maxVals.AddRange(maxVals);

            ret = PwrSnsrLib32.PwrSnsr_GetStartTimes(MeterHandle, "CH1", siz, strtVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_startVals.AddRange(strtVals);

            ret = PwrSnsrLib32.PwrSnsr_GetSequenceNumbers(MeterHandle, "CH1", siz, seqVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_seqVals.AddRange(seqVals);

            ret = PwrSnsrLib32.PwrSnsr_GetDurations(MeterHandle, "CH1", siz, durVals, ref rtnCnt);
            Utilities.ThrowifError(ret);
            m_durVals.AddRange(durVals);
        }

        private void btnAcquireMeasBuff_Click(object sender, EventArgs e)
        {
            //if (m_meter == null) return;
            Cursor = Cursors.WaitCursor;
            Update();
            try
            {
                //setGateQualTimes();
                AcquireMeasBuff();
                GetArrays();
                //OpenMSExcel();
                UpdateChart();
                grpBxShow.Enabled = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Acquire Measure Buffered Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            Cursor = Cursors.Default;
        }


        private void setupTrigSrcs()
        {
            trigSrcCbox.Items.Clear();

            trigSrcCbox.Items.Add(TRIGSRC_ENUM.TRINT);
            trigSrcCbox.Items.Add(TRIGSRC_ENUM.TREXT);
            //trigSrcCbox.Items.Add(TRIGSRC_ENUM.TRMASTER);
            //trigSrcCbox.Items.Add(TRIGSRC_ENUM.TRSLAVE);
            trigSrcCbox.SelectedItem = TRIGSRC_ENUM.TRINT;

            trigModeCbox.Items.Clear();
            trigModeCbox.Items.Add(TRIGMODE_ENUM.TRPK2PK);
            trigModeCbox.Items.Add(TRIGMODE_ENUM.TRAUTO);
            trigModeCbox.Items.Add(TRIGMODE_ENUM.TRNORM);
            trigModeCbox.Items.Add(TRIGMODE_ENUM.TRFREE);
            trigModeCbox.SelectedItem = TRIGMODE_ENUM.TRNORM;

            cboxUnits.Items.Clear();
            cboxUnits.Items.Add("dBm");
            cboxUnits.Items.Add("Watts");
            //cboxUnits.Items.Add("Volts");
            cboxUnits.SelectedItem = "dBm";
        }

        private void setupMbufControls()
        {
            cBoxMBstart.SelectedIndex = 0;
            cBoxMBgate.SelectedIndex = 0;
        }

        float yMax, yMin, xMax, xMin;

        private void chkBxRunCont_CheckedChanged(object sender, EventArgs e)
        {
            chkBxRunCont.Text = chkBxRunCont.Checked ? "Stop " : "Run Continuous";
            timer1.Enabled = chkBxRunCont.Checked;
            if (chkBxRunCont.Text.Contains("Stop"))
                chkBxRunCont.BackColor = Color.Red;
            else
                chkBxRunCont.BackColor = Color.MediumSeaGreen;

        }

        Mutex m_mutex = new Mutex();
        /// <summary>
        /// Time event for displaying traces.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1_Tick(object sender, EventArgs e)
        {
            try
            {
                //Try to get the mutex for 5 milliseconds. If attempt fails, move on so we
                //don't accumulate timer events.
                if (m_mutex.WaitOne(5))
                {
                    //Display a new trace.
                    DisplayTrace();
                }
            }
            catch
            {
            }
            try
            {
                //release the mutex.
                m_mutex.ReleaseMutex();
            }
            catch
            {
            }
        }

        bool tbChanged = false;
        private void cboxTimeBase_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (!string.IsNullOrWhiteSpace(cboxTimeBase.Text))
                {
                    //Parse the current text in the combobox and set the meter's timebase.
                    int ret = PwrSnsrLib32.PwrSnsr_SetTimebase(MeterHandle, (float)Utilities.GetTimebaseFromLabel(cboxTimeBase.Text));
                    Utilities.ThrowifError(ret);

                     tbChanged = true;
                    // displayUpdate(1);

                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            //chart1.ChartAreas[0].RecalculateAxesScale();
            //chart1.ChartAreas[0].AxisY.Maximum = chart1.ChartAreas[0].AxisY.Maximum;
            //chart1.ChartAreas[0].AxisY.Minimum = chart1.ChartAreas[0].AxisY.Minimum;

        }

        private void btnSnglTrc_Click(object sender, EventArgs e)
        {
            try
            {
                DisplayTrace();

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void tBoxHoldTime_KeyPress(object sender, KeyPressEventArgs e)
        {
            TextBox tb = (TextBox)sender;

            if (e.KeyChar == 13 && tBoxHoldTime.Text.Length > 0)
            {
                float htime = Convert.ToSingle(tBoxHoldTime.Text);
                int ret = PwrSnsrLib32.PwrSnsr_SetTrigHoldoff(MeterHandle, htime);
                Utilities.ThrowifError(ret);
            }

        }

        private void tBoxTrigPos_KeyPress(object sender, KeyPressEventArgs e)
        {

            if (e.KeyChar == 13 && tBoxTrigPos.Text.Length > 0)
            {
                float tPos = Convert.ToSingle(tBoxTrigPos.Text);
                int ret = PwrSnsrLib32.PwrSnsr_SetTrigVernier(MeterHandle, tPos);
                Utilities.ThrowifError(ret);
            }

        }

        private void cBoxAvgs_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (!string.IsNullOrWhiteSpace(cboxTimeBase.Text))
                {
                    //Parse the current text in the combobox and set the meter's averaging.
                    int ret = PwrSnsrLib32.PwrSnsr_SetAverage(MeterHandle, "CH1", int.Parse(cBoxAvgs.Text));
                    Utilities.ThrowifError(ret);

                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void rdoPosSlp_CheckedChanged(object sender, EventArgs e)
        {
            try
            {
                PwrSnsrTriggerSlopeEnum slpe = rdoNegSlp.Checked ? PwrSnsrTriggerSlopeEnum.TriggerSlopeNegative
                    : PwrSnsrTriggerSlopeEnum.TriggerSlopePositive;
                int ret = PwrSnsrLib32.PwrSnsr_SetTrigSlope(MeterHandle, slpe);
                Utilities.ThrowifError(ret);

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void trigLevTbox_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == 13 && trigLevTbox.Text.Length > 0)
            {
                float trLev = Convert.ToSingle(trigLevTbox.Text);
                int ret = PwrSnsrLib32.PwrSnsr_SetTrigLevel(MeterHandle, trLev);
                Utilities.ThrowifError(ret);

            }

        }

        private void trigDlyTbox_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == 13 && trigDlyTbox.Text.Length > 0)
            {
                float trDly = Convert.ToSingle(trigDlyTbox.Text.ToUpper());
                int ret = PwrSnsrLib32.PwrSnsr_SetTrigDelay(MeterHandle, trDly);
                Utilities.ThrowifError(ret);
            }

        }

        private void trigSrcCbox_Click(object sender, EventArgs e)
        {
            trigSrcCbox.DropDownStyle = ComboBoxStyle.DropDownList;
            trigSrcCbox.DroppedDown = true;
        }

        private void trigSrcCbox_DropDownClosed(object sender, EventArgs e)
        {
            trigSrcCbox.DropDownStyle = ComboBoxStyle.Simple;
            string trgSrc = trigSrcCbox.SelectedItem.ToString();
            PwrSnsrTriggerSourceEnum trSrc = PwrSnsrTriggerSourceEnum.TriggerSourceChannel1; ;
            if (trgSrc.ToLower().Contains("int"))
                trSrc = PwrSnsrTriggerSourceEnum.TriggerSourceChannel1;
            else if (trgSrc.ToLower().Contains("ext"))
                trSrc = PwrSnsrTriggerSourceEnum.TriggerSourceExternal;
            int ret = PwrSnsrLib32.PwrSnsr_SetTrigSource(MeterHandle, trSrc);
            Utilities.ThrowifError(ret);

        }

        private void trigModeCbox_Click(object sender, EventArgs e)
        {
            trigModeCbox.DropDownStyle = ComboBoxStyle.DropDownList;
            trigModeCbox.DroppedDown = true;
        }

        private void trigModeCbox_DropDownClosed(object sender, EventArgs e)
        {
            trigModeCbox.DropDownStyle = ComboBoxStyle.Simple;
            string trgMode = trigModeCbox.SelectedItem.ToString();
            PwrSnsrTriggerModeEnum trMode = PwrSnsrTriggerModeEnum.TriggerModeNormal;
            if (trgMode.ToLower().Contains("norm"))
                trMode = PwrSnsrTriggerModeEnum.TriggerModeNormal;
            else if (trgMode.ToLower().Contains("auto"))
                trMode = PwrSnsrTriggerModeEnum.TriggerModeAuto;
            else if (trgMode.ToLower().Contains("free"))
                trMode = PwrSnsrTriggerModeEnum.TriggerModeFreerun;

            int ret = PwrSnsrLib32.PwrSnsr_SetTrigMode(MeterHandle, trMode);
            Utilities.ThrowifError(ret);
        }

        private void chkHoldMode_CheckedChanged(object sender, EventArgs e)
        {
            //chkHoldMode.Text = chkHoldMode.Checked ? "Gap " : "Normal";

            PwrSnsrHoldoffModeEnum hMode = chkHoldMode.Checked ? PwrSnsrHoldoffModeEnum.HoldoffModeGap
                : PwrSnsrHoldoffModeEnum.HoldoffModeNormal;

            int ret = PwrSnsrLib32.PwrSnsr_SetTrigHoldoffMode(MeterHandle, hMode);
            Utilities.ThrowifError(ret);

        }

        private void btnReplot_Click(object sender, EventArgs e)
        {
            reGraphChart();
        }

        void reGraphChart()
        {
            //tBoxStartPt  tBoxCount chkBxMax chkBxMin chkBxAvg  chart1.Series[0].Points.AddXY(start + ((i * timebase * 10f) / ((float)data.Length)), data[i]);
            int startPt = Convert.ToInt32(tBoxStartPt.Text);
            int numPts = Convert.ToInt32(tBoxCount.Text);
            int k;

            if (numPts > m_startVals.Count) return;
            if (startPt + numPts > m_startVals.Count) return;

            chartMeasBuff.SuspendLayout();

            var maxSeries = CloneSeries(chartMeasBuff.Series["Max"], "Max");
            var minSeries = CloneSeries(chartMeasBuff.Series["Min"], "Min");
            var avgSeries = CloneSeries(chartMeasBuff.Series["Avg"], "Avg");
            chartMeasBuff.Series.Remove(chartMeasBuff.Series["Max"]);
            chartMeasBuff.Series.Add(maxSeries);

            chartMeasBuff.Series.Remove(chartMeasBuff.Series["Min"]);
            chartMeasBuff.Series.Add(minSeries);

            chartMeasBuff.Series.Remove(chartMeasBuff.Series["Avg"]);
            chartMeasBuff.Series.Add(avgSeries);

            maxSeries.ChartType = SeriesChartType.Line;
            minSeries.ChartType = SeriesChartType.Line;
            avgSeries.ChartType = SeriesChartType.Line;

            maxSeries.Color = Color.Orange;
            minSeries.Color = Color.CornflowerBlue;
            avgSeries.Color = Color.Yellow;

            if (chkBxMax.Checked)
            {
                maxSeries.Points.SuspendUpdates();
                for (int j = 0; j < numPts; j++)   //startPt + numPts;
                {
                    k = startPt + j;
                    maxSeries.Points.AddXY(m_startVals[k], m_maxVals[k]);
                }
            }

            if (chkBxMin.Checked)
            {
                minSeries.Points.SuspendUpdates();
                for (int j = 0; j < numPts; j++)   //startPt + numPts;
                {
                    k = startPt + j;
                    minSeries.Points.AddXY(m_startVals[k], m_minVals[k]);
                }

            }

            if (chkBxAvg.Checked)
            {
                avgSeries.Points.SuspendUpdates();
                for (int j = 0; j < numPts; j++)   //startPt + numPts;
                {
                    k = startPt + j;
                    avgSeries.Points.AddXY(m_startVals[k], m_avgVals[k]);
                }

            }

            chartMeasBuff.ResumeLayout();

        }

        void UpdateChart()
        {
            chartMeasBuff.ChartAreas[0].AxisY.MajorGrid.Interval = 10;
            chartMeasBuff.ChartAreas[0].AxisY.Interval = 10;


            chartMeasBuff.SuspendLayout();
            var maxSeries = CloneSeries(chartMeasBuff.Series["Max"], "Max");
            if (cbxMBmax.Checked)
            {
                maxSeries.ChartType = SeriesChartType.Line;
                maxSeries.Color = Color.Orange;
                maxSeries.Points.SuspendUpdates();
                chartMeasBuff.Series.Remove(chartMeasBuff.Series["Max"]);
                chartMeasBuff.Series.Add(maxSeries);
                //chartMeasBuff.ChartAreas[0].AxisX.LabelStyle.Format = "{0.###E-000}"; 
                maxSeries.Points.DataBindXY(m_startVals, m_maxVals);
            }

            var minSeries = CloneSeries(chartMeasBuff.Series["Min"], "Min");
            if (cbxMBmin.Checked)
            {
                minSeries.ChartType = SeriesChartType.Line;
                minSeries.Color = Color.CornflowerBlue;
                minSeries.Points.SuspendUpdates();
                chartMeasBuff.Series.Remove(chartMeasBuff.Series["Min"]);
                chartMeasBuff.Series.Add(minSeries);
                //chartMeasBuff.ChartAreas[0].AxisX.LabelStyle.Format = "{ 0.###E-000}"; 
                minSeries.Points.DataBindXY(m_startVals, m_minVals);
            }

            var avgSeries = CloneSeries(chartMeasBuff.Series["Avg"], "Avg");
            avgSeries.ChartType = SeriesChartType.Line;
            avgSeries.Color = Color.Yellow;
            avgSeries.Points.SuspendUpdates();
            chartMeasBuff.Series.Remove(chartMeasBuff.Series["Avg"]);
            chartMeasBuff.Series.Add(avgSeries);
            //chartMeasBuff.ChartAreas[0].AxisX.LabelStyle.Format = "{ 0.###E-000}"; 
            avgSeries.Points.DataBindXY(m_startVals, m_avgVals);

            chartMeasBuff.ChartAreas[0].AxisX.Interval = m_startVals.Max() / 10;
            chartMeasBuff.ChartAreas[0].AxisX.LabelStyle.Format = "{0.####}";

            if (cbxMBmax.Checked) maxSeries.Points.ResumeUpdates();
            if (cbxMBmin.Checked) minSeries.Points.ResumeUpdates();
            avgSeries.Points.ResumeUpdates();
            chartMeasBuff.ResumeLayout();

        }

        public static Series CloneSeries(Series sourceSeries, string newName)
        {
            // Sanity-check the parameters.
            if (sourceSeries == null)
            {
                throw new ArgumentException("Invalid source series");
            }
            if (newName == null || newName.Length < 1)
            {
                throw new ArgumentException("Invalid name");
            }

            // Create a new empty series.
            Series clone = new Series(newName);

            // Copy all properties from the template series to the clone series.
            foreach (PropertyDescriptor prop in TypeDescriptor.GetProperties(sourceSeries))
            {
                // Exclude the name and read-only properties.
                if (prop.IsReadOnly || prop.Name == "Name")
                {
                }

                continue;
                //               prop.SetValue(clone, prop.GetValue(sourceSeries));
            }

            return clone;
        }

        void DisplayTrace()
        {
            //If the m_meter is not open, return.
            if (!MeterOpen)
            {
                return;
            }

            if (tbChanged) tbChanged = false;

            ////float[] dataArray = null;

            //Fetch the waveform
            int traceCount = 501;
            string chan = "CH1";
            float[] trace = new float[traceCount];
            int actualSize = 0;

            int ret = PwrSnsrLib32.PwrSnsr_FetchWaveform(MeterHandle, chan, traceCount, trace, ref actualSize);
            Utilities.ThrowifError(ret);
            //Cast the data to a float array
            var data = trace.Cast<float>().ToArray();
            //Get the timebase.
            float timebase = 0.0f;
            ret = PwrSnsrLib32.PwrSnsr_GetTimebase(MeterHandle, ref timebase);
            Utilities.ThrowifError(ret);
            //Get the trig position
            float position = 0.0f;
            ret = PwrSnsrLib32.PwrSnsr_GetTrigVernier(MeterHandle, ref position);
            Utilities.ThrowifError(ret);

            //Get trigger delay
            float delay = 0.0f;
            ret = PwrSnsrLib32.PwrSnsr_GetTrigDelay(MeterHandle, ref delay);
            Utilities.ThrowifError(ret);
            //Get the start of the trace.
            float start = (-(position * timebase) + delay);
            xMin = start;
            xMax = start + timebase * 10;

            float sfact;
            if (cboxTimeBase.SelectedItem.ToString().Contains(" μ"))
            {
                string[] st = cboxTimeBase.SelectedItem.ToString().Split(new char[] { ' ' });
                float perDiv = Convert.ToSingle(st[0]);
                if (perDiv >= 100)
                {
                    sfact = 1E3f;
                    chart1.ChartAreas[0].AxisX.Title = "Time " + "(msec)";
                }
                else
                {
                    sfact = 1E6f;
                    chart1.ChartAreas[0].AxisX.Title = "Time " + "(μsec)";
                }

            }
            else if (cboxTimeBase.SelectedItem.ToString().Contains(" n"))
            {
                string[] st = cboxTimeBase.SelectedItem.ToString().Split(new char[] { ' ' });
                float perDiv = Convert.ToSingle(st[0]);
                if (perDiv >= 100)
                {
                    sfact = 1E6f;
                    chart1.ChartAreas[0].AxisX.Title = "Time " + "(μsec)";
                }
                else
                {
                    sfact = 1E9f;
                    chart1.ChartAreas[0].AxisX.Title = "Time " + "(nsec)";
                }


            }
            else if (cboxTimeBase.SelectedItem.ToString().Contains(" m"))
            {
                sfact = 1E3f;
                chart1.ChartAreas[0].AxisX.Title = "Time " + "(msec)";

            }
            else
                sfact = 1.0f;

            float tbase = timebase * sfact;
            start *= sfact;
            tbase = (float)Math.Round(tbase, 1);
            start = (float)Math.Round(start, 1);


            chart1.SuspendLayout();

            //Clear all data points.
            chart1.Series[0].Points.SuspendUpdates();
            chart1.Series[0].Points.Clear();

            //Add each point to the chart data series. X = time, y = power.
            for (int i = 0; i < data.Length; i++)
            {
                chart1.Series[0].Points.AddXY(start + ((i * tbase * 10f) / ((float)data.Length)), data[i]);
                //                xyseries.Points.AddXY(start + ((i * tbase * 10f) / ((float)data.Length)), data[i]);
            }

            chart1.ChartAreas[0].AxisX.Maximum = Convert.ToDouble(chart1.Series[0].Points[data.Length - 1].XValue);        //Convert.ToDouble(xyseries.Points[data.Length - 1].XValue);
            chart1.ChartAreas[0].AxisX.Minimum = Convert.ToDouble(chart1.Series[0].Points[0].XValue);                      //Convert.ToDouble(xyseries.Points[0].XValue);
            chart1.ChartAreas[0].AxisX.IntervalType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.Number;              chart1.ChartAreas[0].AxisX.IntervalOffsetType = System.Windows.Forms.DataVisualization.Charting.DateTimeIntervalType.Number;
            chart1.ChartAreas[0].AxisX.IntervalAutoMode = System.Windows.Forms.DataVisualization.Charting.IntervalAutoMode.FixedCount;
            chart1.ChartAreas[0].AxisX.IntervalOffset = 0;


            chart1.ChartAreas[0].AxisX.Interval = chart1.ChartAreas[0].AxisX.MajorGrid.Interval;
            chart1.ResumeLayout();

        }

        private void rescaleChart(float xMin, float xDelta)
        {
            float yMax = Convert.ToSingle(tBoxYmax.Text);
            float yMin = Convert.ToSingle(tBoxYmin.Text);
            chart1.ChartAreas[0].AxisY.Maximum = yMax;
            chart1.ChartAreas[0].AxisY.Minimum = yMin;
            chart1.ChartAreas[0].AxisY.Interval = 8;

            chart1.ChartAreas[0].AxisX.LabelStyle.Format = "g4";

            chart1.ChartAreas[0].AxisX.CustomLabels.SuspendUpdates();
            chart1.ChartAreas[0].RecalculateAxesScale();
            //chart1.ChartAreas[0].AxisX.Minimum = chart1.ChartAreas[0].AxisX.Minimum;
            //chart1.ChartAreas[0].AxisX.Maximum = chart1.ChartAreas[0].AxisX.Maximum;
            chart1.ChartAreas[0].AxisX.MajorGrid.Interval = (chart1.ChartAreas[0].AxisX.Maximum - chart1.ChartAreas[0].AxisX.Minimum) / 10;  // use 10 division horiz
            chart1.ChartAreas[0].AxisY.MajorGrid.Interval = (chart1.ChartAreas[0].AxisY.Maximum - chart1.ChartAreas[0].AxisY.Minimum) / 8;   // use 8 divisions vert
            //chart1.ChartAreas[0].AxisX.Interval = (chart1.ChartAreas[0].AxisX.Maximum - chart1.ChartAreas[0].AxisX.Minimum) / 10f;
            chart1.ChartAreas[0].AxisX.RoundAxisValues();

            double intvl = chart1.ChartAreas[0].AxisX.MajorGrid.Interval;
            chart1.ChartAreas[0].AxisX.Interval = chart1.ChartAreas[0].AxisX.MajorGrid.Interval;
            chart1.ChartAreas[0].AxisX.CustomLabels.Clear();
            chart1.ChartAreas[0].AxisX.CustomLabels.Invalidate();

            chart1.ChartAreas[0].AxisX.IsLabelAutoFit = true;
            //chart1.ChartAreas[0].AxisX.LabelAutoFitStyle = LabelAutoFitStyles.DecreaseFont | LabelAutoFitStyles.IncreaseFont;
            chart1.ChartAreas[0].AxisX.LabelStyle.IsStaggered = false;
            chart1.ChartAreas[0].AxisX.LabelStyle.Enabled = true;

            chart1.ChartAreas[0].IsSameFontSizeForAllAxes = true;

            double Offset = Math.Round(chart1.ChartAreas[0].AxisX.Minimum, 2);   //Convert.ToDouble((int)chart1.ChartAreas[0].AxisX.Minimum); //
            Offset = Convert.ToDouble(Convert.ToInt32(Offset));
            double min = chart1.ChartAreas[0].AxisX.Minimum;
            double fudge = 8.0;   // 3.5;
                                  //chart1.ChartAreas[0].AxisX.CustomLabels.Add(min, min + intvl, string.Format("{0:N1}", chart1.ChartAreas[0].AxisX.Minimum));

            for (int div = 0; div < 10; div++)
                //               chart1.ChartAreas[0].AxisX.CustomLabels.Add(fudge * Offset + div * intvl, Math.Round((min + (div + 1) * intvl)), (xMin + div * xDelta).ToString());
                chart1.ChartAreas[0].AxisX.CustomLabels.Add(min + div * intvl - fudge, min + div * intvl + fudge, (xMin + div * xDelta).ToString());

            chart1.ChartAreas[0].AxisX.CustomLabels.Add(min + 10 * intvl - fudge, min + 10 * intvl + fudge, (xMin + 10 * xDelta).ToString());

            chart1.ChartAreas[0].AxisX.CustomLabels.ResumeUpdates();
        }

        string grpTitle = "";
        string excelFileName = "";

        public Microsoft.Office.Interop.Excel._Application xla;
        public Microsoft.Office.Interop.Excel._Application xla2;
        public Microsoft.Office.Interop.Excel.Worksheet xlws;
        public Microsoft.Office.Interop.Excel.Worksheet xlwscurrent;
        public Microsoft.Office.Interop.Excel.Workbook OpenWB = null;
        public Microsoft.Office.Interop.Excel.Workbook OpenWB2 = null;
        object missing = Type.Missing;

        MSExcel.Worksheet xlwsnow = null;
        List<string> shtNames = new List<string>();
        //--------------------------------------------------------------------
        private void OpenMSExcel()
        //--------------------------------------------------------------------
        {
            string appDir = Environment.CurrentDirectory;
            int idx = appDir.IndexOf("bin", 0);
            string LOCAL_progdrive = appDir.Substring(0, idx) + "TestData\\";
            //string LOCAL_progdrive = @"C:\tmp\MBuffDemo2012\TestData\";
            string fname = LOCAL_progdrive + "Mbuf_TestBedBurstCapture_latest.xlsx";

            if (xla == null)
            {

                //if (using2530)
                //{
                xla = new Microsoft.Office.Interop.Excel.Application();
                try
                {
                    OpenWB = xla.Workbooks.Open(fname, 0, false, 5, missing, missing, true,
                                                Microsoft.Office.Interop.Excel.XlPlatform.xlWindows, "\t", false, false, 0, true, 1, 0);
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Open MSExcel workbook Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }

                foreach (Microsoft.Office.Interop.Excel.Worksheet thisWorksheet in xla.Worksheets)
                {
                    shtNames.Add(thisWorksheet.Name);
                }

            }
            //MSExcel worksheet index start with 1
            xlws = (MSExcel.Worksheet)xla.Sheets["Template"];
            //xlws = (MSExcel.Worksheet)xla.Sheets["Sheet1"];
            xla.Visible = true;
            xla.DisplayAlerts = false;
            string shtname = "";

            shtname = txtbxModelNo.Text + "_" + txtbxSerialNo.Text + grpTitle;

            MSExcel.Worksheet xlwscurrent;
            xlws.Copy(missing, After: xla.Sheets[xla.Sheets.Count]);
            xlwscurrent = (MSExcel.Worksheet)xla.Sheets["Template (2)"];
            foreach (Microsoft.Office.Interop.Excel.Worksheet thisWorksheet in xla.Worksheets)
            {
                string ws = thisWorksheet.Name;
                if (thisWorksheet.Name.Equals(shtname))
                {
                    ((Microsoft.Office.Interop.Excel.Worksheet)xla.Sheets[ws]).Delete();
                }
            }
            xla.DisplayAlerts = true;
            xlwscurrent.Name = shtname;
            xlwsnow = xlwscurrent;

            int count = Convert.ToInt32(tBoxStopCnt.Text);

            float[,] f_arr_val = new float[count, 1];
            double[,] d_arr_val = new double[count, 1];
            long[,] i_arr_val = new long[count, 1];

            WriteArrayFloat(count, 3, m_durVals, f_arr_val, xlwscurrent);
            WriteArrayDouble(count, 4, m_startVals, d_arr_val, xlwscurrent);
            if (cbxMBmax.Checked)
                WriteArrayFloat(count, 7, m_maxVals, f_arr_val, xlwscurrent);
            if (cbxMBmin.Checked)
                WriteArrayFloat(count, 5, m_minVals, f_arr_val, xlwscurrent);

            float maxVal = 0;
            float minVal = 0;
            var maxXVal = m_startVals.Max();
            if (cbxMBmax.Checked)
                maxVal = m_maxVals.Max() + 5;
            if (cbxMBmin.Checked)
                minVal = m_minVals.Min() - 1;
            else
                minVal = m_avgVals.Min() - 1;

            MSExcel.Range chartRange;


            //maxVal = m_maxVals.Max() + 5;
            //minVal = m_minVals.Min() - 1;

            //if (startPt != 0)
            //{
            //    int end = startPt + 200;
            //    limit_maxVals = m_maxVals.GetRange(startPt, startPt + 200);
            //    limit_minVals = m_minVals.GetRange(startPt, end);
            //    maxVal =limit_maxVals.Max() + 5;
            //    minVal = limit_minVals.Min() - 1;

            //}


            //WriteArrayFloat(count, 3, m_durVals, f_arr_val, xlwscurrent);
            //WriteArrayFloat(count, 4, m_startVals, f_arr_val, xlwscurrent);
            //WriteArrayFloat(count, 5, m_minVals, f_arr_val, xlwscurrent, strtpt: startPt);
            //WriteArrayFloat(count, 6, m_avgVals, f_arr_val, xlwscurrent);
            //WriteArrayFloat(count, 7, m_maxVals, f_arr_val, xlwscurrent, strtpt: startPt);

            count = count + 5;
            if (grpTitle.Contains("Var PRF"))
            {
                xlwscurrent.Cells[5, 8] = "delta start";
                xlwscurrent.Cells[6, 8] = "time";
                //xlwscurrent.Cells[6, 9] = "seconds";
                //xlwscurrent.Cells[5, 9] = "time";
                MSExcel.Range rng = xlwscurrent.get_Range("H7", "H" + count);
                rng.Formula = "=D7-D6";
                //rng = xlwscurrent.get_Range("I7", "I" + count);
                //rng.Formula = "=H7 * 0.00000001";

                MSExcel.ChartObjects xlCharts = (MSExcel.ChartObjects)xlwscurrent.ChartObjects(Type.Missing);
                //MSExcel.ChartObject myChart = ( MSExcel.ChartObject)xlCharts.Add(10, 80, 300, 250);
                //MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(1050, 865, 690, 265);
                MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(500, 80, 690, 265);
                MSExcel.Chart chartPage = myChart.Chart;
                chartRange = xlwscurrent.get_Range("H7", "I" + count);
                //endPt = startPt + maxPt;
                //chartRange = xlwscurrent.get_Range("H" + startPt, "I" + endPt);

                chartPage.ChartType = MSExcel.XlChartType.xlXYScatterSmoothNoMarkers;
                chartPage.HasTitle = true;
                chartPage.ChartTitle.Text = grpTitle + " (delta start time vs start time)";
                chartPage.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);
                //chartPage.HasAxis = true;

                MSExcel.Axis yAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "Delta Start TIme (Sec)";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                //yAxis.HasMajorGridlines = true;
                //yAxis.HasMinorGridlines = false;


                //yAxis.MaximumScale = maxVal;
                //yAxis.MinimumScale = minVal;
                ////yAxis.MaximumScaleIsAuto = true;
                ////yAxis.MinimumScaleIsAuto = true;
                ////yAxis.CrossesAt = -0.0003;
                //yAxis.CrossesAt = yAxis.MinimumScale;

                MSExcel.Axis xAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "Time (Sec)";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = true;
                xAxis.MaximumScale = m_startVals.Max();
                xAxis.MinimumScale = 0;
                //xAxis.Select();
                //xAxis.TickLabels.Orientation = 35;
                //xAxis.TickLabels.NumberFormat ="0.###E-000";
                xAxis.TickLabels.Font.Size = chartPage.ChartTitle.Characters.Font.Size;
                xAxis.TickLabels.Font.Size = 8;
                MSExcel.SeriesCollection oSeriesCollection = (MSExcel.SeriesCollection)myChart.Chart.SeriesCollection(missing);

                MSExcel.Series delta_series1 = oSeriesCollection.NewSeries();
                delta_series1.Values = xlwscurrent.get_Range("H7", "H" + count);
                delta_series1.XValues = xlwscurrent.get_Range("D7", "D" + count);
                //delta_series1.XValues = xlwscurrent.get_Range("H7", "H" + count);
                delta_series1.Name = "Delta Start";
            }
            else if (grpTitle.Contains("Var Width"))
            {

                //xlwscurrent.Cells[5, 8] = "delta start";
                //xlwscurrent.Cells[6, 8] = "ticks";
                //xlwscurrent.Cells[5, 9] = "time";
                //xlwscurrent.Cells[6, 9] = "seconds";
                MSExcel.Range rng = xlwscurrent.get_Range("H7", "H" + count);
                //rng.Formula = "=D7-D6";
                //rng = xlwscurrent.get_Range("I7", "I" + count);
                //rng.Formula = "=H7 * 0.00000001";

                MSExcel.ChartObjects xlCharts = (MSExcel.ChartObjects)xlwscurrent.ChartObjects(Type.Missing);
                //MSExcel.ChartObject myChart = ( MSExcel.ChartObject)xlCharts.Add(10, 80, 300, 250);
                //MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(1050, 865, 690, 265);
                MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(500, 80, 690, 265);
                MSExcel.Chart chartPage = myChart.Chart;
                chartRange = xlwscurrent.get_Range("C7", "D" + count);

                chartPage.ChartType = MSExcel.XlChartType.xlXYScatterSmoothNoMarkers;
                chartPage.HasTitle = true;
                chartPage.ChartTitle.Text = grpTitle + " (duration vs start time)";
                chartPage.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);
                //chartPage.HasAxis = true;

                MSExcel.Axis yAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "Pulse Period (Sec)";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                //yAxis.HasMajorGridlines = true;
                //yAxis.HasMinorGridlines = false;


                //yAxis.MaximumScale = maxVal;
                //yAxis.MinimumScale = minVal;
                ////yAxis.MaximumScaleIsAuto = true;
                ////yAxis.MinimumScaleIsAuto = true;
                ////yAxis.CrossesAt = -0.0003;
                //yAxis.CrossesAt = yAxis.MinimumScale;

                MSExcel.Axis xAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "Time (Sec)";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = true;
                xAxis.MaximumScale = m_startVals.Max();
                xAxis.MinimumScale = 0;
                //xAxis.Select();
                //xAxis.TickLabels.Orientation = 35;
                //xAxis.TickLabels.NumberFormat ="0.###E-000";
                xAxis.TickLabels.Font.Size = chartPage.ChartTitle.Characters.Font.Size;
                xAxis.TickLabels.Font.Size = 8;
                MSExcel.SeriesCollection oSeriesCollection = (MSExcel.SeriesCollection)myChart.Chart.SeriesCollection(missing);

                MSExcel.Series delta_series1 = oSeriesCollection.NewSeries();
                delta_series1.Values = xlwscurrent.get_Range("C7", "C" + count);
                delta_series1.XValues = xlwscurrent.get_Range("D7", "D" + count);
                //delta_series1.XValues = xlwscurrent.get_Range("H7", "H" + count);
                delta_series1.Name = "Delta Start";

            }
            else if (grpTitle.Contains("IFF"))
            {


                MSExcel.ChartObjects xlCharts = (MSExcel.ChartObjects)xlwscurrent.ChartObjects(Type.Missing);
                //MSExcel.ChartObject myChart = ( MSExcel.ChartObject)xlCharts.Add(10, 80, 300, 250);
                //MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(1050, 865, 690, 265);
                MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(500, 80, 690, 265);  //was395
                MSExcel.Chart chartPage = myChart.Chart;
                MSExcel.ChartObject myChart2 = (MSExcel.ChartObject)xlCharts.Add(500, 360, 690, 265);
                MSExcel.Chart chartPage2 = myChart2.Chart;
                //chartRange = xlwscurrent.get_Range("D6", "G" + count);
                MSExcel.Range rng = xlwscurrent.get_Range("H7", "H" + count);
                rng.Formula = "=D7-D6";
                //rng = xlwscurrent.get_Range("I7", "I" + count);
                //rng.Formula = "=D7 * 10000000.0";

                //startPt = startPt + 7;
                //endPt = startPt + 200;
                chartRange = xlwscurrent.get_Range("H7", "I" + count);
                //chartRange = xlwscurrent.get_Range("H" + startPt, "I" + endPt);
                chartPage.ChartType = MSExcel.XlChartType.xlXYScatter;
                xlwscurrent.Cells[5, 8] = "delta start";
                xlwscurrent.Cells[6, 8] = "time";

                //chartPage.ChartType = MSExcel.XlChartType.xlXYScatterLines;
                //chartPage.ChartType = MSExcel.XlChartType.xlLineMarkers;
                //chartPage.ChartType = MSExcel.XlChartType.xlXYScatterSmoothNoMarkers;
                chartPage.HasTitle = true;
                chartPage.ChartTitle.Text = grpTitle + " (delta start time vs start time)";
                chartPage.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);
                //chartPage.HasAxis = true;

                MSExcel.Axis yAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "delta time";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                yAxis.HasMajorGridlines = true;
                yAxis.HasMinorGridlines = false;

                MSExcel.SeriesCollection oSeriesCollection = (MSExcel.SeriesCollection)myChart.Chart.SeriesCollection(missing);
                MSExcel.Series delta_series1 = oSeriesCollection.NewSeries();
                delta_series1.Values = xlwscurrent.get_Range("H7", "H" + count);
                delta_series1.XValues = xlwscurrent.get_Range("D7", "D" + count);
                delta_series1.Name = "Delta Start";
                //delta_series1.Values = xlwscurrent.get_Range("H"+ startPt, "H" + endPt);
                //delta_series1.XValues = xlwscurrent.get_Range("D"+startPt, "D" + endPt );
                //delta_series1.Name = "Delta Start";


                //yAxis.MaximumScale = maxVal;
                //yAxis.MinimumScale = minVal;
                yAxis.MaximumScaleIsAuto = true;
                yAxis.MinimumScaleIsAuto = true;
                //yAxis.CrossesAt = -0.0003;
                yAxis.CrossesAt = yAxis.MinimumScale;

                MSExcel.Axis xAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "Seconds";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = true;
                xAxis.MaximumScale = m_startVals.Max();
                xAxis.MinimumScale = 0;
                //xAxis.Select();
                //xAxis.TickLabels.Orientation = 35;
                //xAxis.TickLabels.NumberFormat ="0.###E-000";
                xAxis.TickLabels.Font.Size = chartPage.ChartTitle.Characters.Font.Size;
                xAxis.TickLabels.Font.Size = 8;

                // show first 20 points
                chartRange = xlwscurrent.get_Range("C6", "D" + count);

                chartPage2.HasTitle = true;
                chartPage2.ChartTitle.Text = grpTitle + " (First 40 points)";
                chartPage2.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);

                chartPage2.ChartType = MSExcel.XlChartType.xlXYScatter;

                yAxis = (MSExcel.Axis)chartPage2.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "micro seconds";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                yAxis.HasMajorGridlines = true;
                yAxis.HasMinorGridlines = false;

                yAxis.MaximumScaleIsAuto = true;
                yAxis.MinimumScaleIsAuto = true;

                yAxis.CrossesAt = yAxis.MinimumScale;

                xAxis = (MSExcel.Axis)chartPage2.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "milliseconds";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = false;
                xAxis.MaximumScale = m_startVals[40];
                xAxis.MinimumScale = 0;

                xAxis.TickLabels.Font.Size = 8;

                MSExcel.SeriesCollection dSeriesCollection = (MSExcel.SeriesCollection)myChart2.Chart.SeriesCollection(missing);
                MSExcel.Series delta_series2 = dSeriesCollection.NewSeries();
                //delta_series2 = (MSExcel.Series)myChart2.Chart.SeriesCollection(missing);
                delta_series2.Values = xlwscurrent.get_Range("H7", "H" + 40);
                delta_series2.XValues = xlwscurrent.get_Range("D7", "D" + 40);
                delta_series2.Name = "Delta Start";


                //MSExcel.Shape tBox;
                //tBox = xlwscurrent.Shapes.AddTextbox(Microsoft.Office.Core.MsoTextOrientation.msoTextOrientationHorizontal, 530, 10, 300, 50);
                //tBox.TextFrame.Characters(System.Type.Missing, System.Type.Missing).Text =
                //    "IFF contains bursts of 10 pulses 10 micro seconds wide spaced 50 microseconds apart with a 500 microsecond gap between bursts ";
               
                //////tBox.Fill.Solid();
                //tBox.Fill.ForeColor.RGB = (int)MSExcel.XlRgbColor.rgbYellow;  // ColorTranslator.ToOle(Color.Yellow);   // 0x00ffff;  // Color.Yellow.ToArgb();
                //// tBox.Fill.ForeColor.RGB = Color.Yellow.ToArgb();   

            }
            else if (grpTitle.Contains("Drop Out"))
            {
                MSExcel.ChartObjects xlCharts = (MSExcel.ChartObjects)xlwscurrent.ChartObjects(Type.Missing);
                MSExcel.ChartObject myChart = (MSExcel.ChartObject)xlCharts.Add(500, 80, 690, 265);  //was395
                MSExcel.ChartObject myChart2 = (MSExcel.ChartObject)xlCharts.Add(500, 360, 690, 265);
                MSExcel.Chart chartPage = myChart.Chart;
                MSExcel.Chart chartPage2 = myChart2.Chart;

                chartRange = xlwscurrent.get_Range("D6", "G" + count);

                chartPage.HasTitle = true;
                chartPage.ChartTitle.Text = grpTitle + " (dBm vs start time)";
                chartPage.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);
                //chartPage.HasAxis = true;

                chartPage.ChartType = MSExcel.XlChartType.xlXYScatterSmoothNoMarkers;

                MSExcel.Axis yAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "dBm";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                yAxis.HasMajorGridlines = true;
                yAxis.HasMinorGridlines = false;

                yAxis.MaximumScale = maxVal;
                yAxis.MinimumScale = minVal;

                //yAxis.MaximumScaleIsAuto = true;
                //yAxis.MinimumScaleIsAuto = true;
                //yAxis.CrossesAt = -0.0003;
                yAxis.CrossesAt = yAxis.MinimumScale;

                MSExcel.Axis xAxis = (MSExcel.Axis)chartPage.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "Seconds";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = false;
                xAxis.MaximumScale = m_startVals.Max();
                xAxis.MinimumScale = 0;

                //xAxis.Select();
                //xAxis.TickLabels.Orientation = 35;
                //xAxis.TickLabels.NumberFormat ="0.###E-000";
                xAxis.TickLabels.Font.Size = chartPage.ChartTitle.Characters.Font.Size;
                xAxis.TickLabels.Font.Size = 8;

                MSExcel.SeriesCollection oSeriesCollection = (MSExcel.SeriesCollection)myChart.Chart.SeriesCollection(missing);
                MSExcel.Series min_series1 = oSeriesCollection.NewSeries();
                MSExcel.Series max_series3 = oSeriesCollection.NewSeries();
                MSExcel.Series avg_series2 = oSeriesCollection.NewSeries(); // gets plotted on top

                min_series1.Border.Color

                    = ColorTranslator.ToOle(Color.CornflowerBlue);     //Color.CornflowerBlue.ToArgb();

                avg_series2.Border.Color = ColorTranslator.ToOle(Color.Yellow);

                max_series3.Border.Color = ColorTranslator.ToOle(Color.Orange);             // Color.Orange.ToArgb();



                //myChart.Chart.PlotArea.Format.Fill.ForeColor.RGB = ColorTranslator.ToOle(Color.Black);
                //myChart.Chart.ChartArea.Format.Fill.ForeColor.RGB = ColorTranslator.ToOle(Color.Gainsboro);

                min_series1.XValues = xlwscurrent.get_Range("D6", "D" + count);
                min_series1.Values = xlwscurrent.get_Range("E6", "E" + count);
                min_series1.Name = "Min Power";
                //min_series1.MarkerStyle = MSExcel.XlMarkerStyle.xlMarkerStyleDot;          
                avg_series2.XValues = xlwscurrent.get_Range("D6", "D" + count);
                avg_series2.Values = xlwscurrent.get_Range("F6", "F" + count);
                avg_series2.Name = "Avg Power";
                max_series3.XValues = xlwscurrent.get_Range("D6", "D" + count);
                max_series3.Values = xlwscurrent.get_Range("G6", "G" + count);
                max_series3.Name = "Max Power";
                //var min = yAxis.MinimumScale;
                //var max = yAxis.MaximumScale;
                //yAxis.CrossesAt = min;
                //yAxis.MaximumScale = max-15;
                //yAxis.MinimumScale = min;

                // now show duration vs start time
                chartRange = xlwscurrent.get_Range("C6", "D" + count);

                chartPage2.HasTitle = true;
                chartPage2.ChartTitle.Text = "Falling Edge Jitter (Duration vs Start time)";
                chartPage2.ChartTitle.Font.Color = ColorTranslator.ToOle(Color.Crimson);

                chartPage2.ChartType = MSExcel.XlChartType.xlXYScatterSmoothNoMarkers;

                yAxis = (MSExcel.Axis)chartPage2.Axes(MSExcel.XlAxisType.xlValue, MSExcel.XlAxisGroup.xlPrimary);
                yAxis.HasTitle = true;
                yAxis.AxisTitle.Text = "micro seconds";
                yAxis.AxisTitle.Orientation = MSExcel.XlOrientation.xlUpward;
                yAxis.HasMajorGridlines = true;
                yAxis.HasMinorGridlines = false;

                yAxis.MaximumScale = m_durVals.Max() * 1.002;
                yAxis.MinimumScale = m_durVals.Min() * .998;

                yAxis.CrossesAt = yAxis.MinimumScale;

                xAxis = (MSExcel.Axis)chartPage2.Axes(MSExcel.XlAxisType.xlCategory, MSExcel.XlAxisGroup.xlPrimary);

                xAxis.HasTitle = true;
                xAxis.AxisTitle.Text = "milliseconds";
                xAxis.HasMajorGridlines = true;
                xAxis.HasMinorGridlines = false;
                xAxis.MaximumScale = m_startVals.Max();
                xAxis.MinimumScale = 0;

                xAxis.TickLabels.Font.Size = 8;

                oSeriesCollection = (MSExcel.SeriesCollection)myChart2.Chart.SeriesCollection(missing);
                min_series1 = oSeriesCollection.NewSeries();
                min_series1.XValues = xlwscurrent.get_Range("D6", "D" + count);
                min_series1.Values = xlwscurrent.get_Range("C6", "C" + count);
                min_series1.Name = "Duration";
            }
            else if (grpTitle.Contains("0.01 %"))
            {
                xlwscurrent.Cells[4, 9] = "Period";
                xlwscurrent.Cells[5, 9] = "Seconds";
                xlwscurrent.Cells[4, 10] = "0.01% Duty";
                xlwscurrent.Cells[5, 10] = "Cycle";

                MSExcel.Range rng = xlwscurrent.get_Range("I7", "I" + count);
                rng.Formula = "=D7-D6";
                rng = xlwscurrent.get_Range("J7", "J" + count);
                rng.Formula = "=(C7/I7) * 100.0";

                //Microsoft.Office.Interop.Excel.ITextBox tbox;
                //Microsoft.Office.Core.MsoTextOrientation orient = new Microsoft.Office.Core.MsoTextOrientation();

                //MSExcel.Shape tBox;
                //tBox = xlwscurrent.Shapes.AddTextbox(Microsoft.Office.Core.MsoTextOrientation.msoTextOrientationHorizontal, 530, 50, 200, 20);
                //tBox.TextFrame.Characters(System.Type.Missing, System.Type.Missing).Text = "% Duty Cycle = (duration / period) * 100";
                //tBox.Fill.Solid();
                ////   tBox.Fill.ForeColor.RGB = 0x00ffff;  // Color.Yellow.ToArgb();

            }

            else if (grpTitle.Contains(" 100 KHz"))
            {
                xlwscurrent.Cells[4, 9] = "Period";
                xlwscurrent.Cells[5, 9] = "Seconds";
                xlwscurrent.Cells[4, 10] = "Frequency";
                xlwscurrent.Cells[5, 10] = "Hz";

                MSExcel.Range rng = xlwscurrent.get_Range("I7", "I" + count);
                rng.Formula = "=D7-D6";
                rng = xlwscurrent.get_Range("J7", "J" + count);
                rng.Formula = "=1/ I7";

                //Microsoft.Office.Interop.Excel.ITextBox tbox;
                //Microsoft.Office.Core.MsoTextOrientation orient = new Microsoft.Office.Core.MsoTextOrientation();

                //MSExcel.Shape tBox;
                //tBox = xlwscurrent.Shapes.AddTextbox(Microsoft.Office.Core.MsoTextOrientation.msoTextOrientationHorizontal, 530, 50, 200, 20);
                //tBox.TextFrame.Characters(System.Type.Missing, System.Type.Missing).Text = "Frequency = 1 / delta start time";
                ////tBox.Fill.Solid();
                //  tBox.Fill.ForeColor.RGB = 0x00ffff;  // Color.Yellow.ToArgb();

            }

            string n = string.Format("-{0:yyyy-MM-dd_hh-mm-ss-tt}.xlsx", DateTime.Now);
            excelFileName = LOCAL_progdrive + "Mbuf_TestBedBurstCapture_" + shtname + n;

            /***************************

                        OpenWB.Close(true, missing, missing);
                        xla.Quit();
                        Marshal.ReleaseComObject(xla);
                        Marshal.FinalReleaseComObject(OpenWB);
                        Marshal.FinalReleaseComObject(xlwscurrent);
            ***************************/
        }

        // fill DataArray
        //private static void WriteArrayFloat(int rows, int columns, List<float> val, MSExcel.Worksheet worksheet)
        private void WriteArrayFloat(int numrows, int column, List<float> arr_list, float[,] val, MSExcel.Worksheet worksheet, int strtpt = 0)
        {
            var startCell = (MSExcel.Range)worksheet.Cells[6, column];
            var endCell = (MSExcel.Range)worksheet.Cells[numrows + 5, column];
            var writeRange = worksheet.Range[startCell, endCell];
            int counter = 0;

            {
                //maxVal = 0;
                //minVal = 1000;
                foreach (float value in arr_list)
                {
                    //if ((column == 7) && (strtpt !=0))
                    //{
                    //    if ((counter > strtpt) && (counter < (strtpt + 200)))
                    //    {
                    //        if (value > limit_maxVal)
                    //        {
                    //            limit_maxVal = value;
                    //        }
                    //    }
                    //}
                    //if ((column == 5) && (strtpt != 0))
                    //{
                    //    if ((counter > strtpt) && (counter < (strtpt + 200)))
                    //    {
                    //        if (value < minVal)
                    //        {
                    //            limit_minVal = value;
                    //        }
                    //    }
                    //}

                    //           lstVals.Items.Add(value);
                    val[counter, 0] = value;
                    counter++;
                }
                writeRange.Value2 = val;
            }
        }

        private void WriteArrayDouble(int numrows, int column, List<double> arr_list, double[,] val, MSExcel.Worksheet worksheet, int strtpt = 0)
        {
            var startCell = (MSExcel.Range)worksheet.Cells[6, column];
            var endCell = (MSExcel.Range)worksheet.Cells[numrows + 5, column];
            var writeRange = worksheet.Range[startCell, endCell];
            int counter = 0;

            {
                foreach (double value in arr_list)
                {
                    val[counter, 0] = value;
                    counter++;
                }
                writeRange.Value2 = val;
            }
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            killExcel();
            this.Dispose();

        }

        private void killExcel()
        {
            if (OpenWB != null)
            {
                OpenWB.Close(false, missing, missing);
                xla.Quit();
                Marshal.ReleaseComObject(xla);
                Marshal.FinalReleaseComObject(OpenWB);
                //Marshal.FinalReleaseComObject(xlwscurrent);
            }
        }

    }
}
