﻿
'***************************** Module Header ******************************\
'Module Name:  MainForm
'Project:      AutoMeasDemo
'Copyright (c) 2019 WTG
'
'Main form for the program.
'
'
'THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
'EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
'WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
'\**************************************************************************
Imports PowerMeterManagement
Public Class MainForm

    Private Sub MainForm_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        For Each Name As String In [Enum].GetNames(GetType(AutoMeasParameter))
            DataGridView1.Rows.Add(True, Name, Nothing, Nothing)
        Next
        FindResources()
    End Sub
    Private m_handle As Integer

    Private MeterOpen As Boolean

    Private Sub FindResources()
        comboBox1.Items.Clear()

        'Clear current list.
        comboBox1.Items.Clear()
        'Find resources and build a pip-delimited string.

        Dim s As String
        Dim buffSize As Integer = 256
        Dim buff(buffSize) As Byte
        Dim err As Integer
        err = PwrSnsrLib32.PwrSnsr_FindResources("|", buffSize, buff)
        Utilities.ThrowifError(err)
        s = Utilities.DecodeAscii(buff)
        'Check if string is valid.
        If Not String.IsNullOrEmpty(s) Then
            'Split string into array.
            Dim resources() As String = s.Split("|")
            'Loop throught the results and add them to the combobox
            For Each resource As String In resources
                comboBox1.Items.Add(resource)
            Next
        End If

        'Select first item if combobox is not empty.
        If comboBox1.Items.Count > 0 Then
            comboBox1.SelectedIndex = 0
        End If
    End Sub

    Private Sub button1_Click(sender As Object, e As EventArgs) Handles button1.Click
        Try
            FindResources()
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub
    Private Sub OpenMeter()
        'Initilize driver using the resource name in combobox1 and also calls reset (*rst) during initlization.
        Dim err As Integer

        err = PwrSnsrLib32.PwrSnsr_init(comboBox1.Text, m_handle)
        Utilities.ThrowifError(err)
        'Set for continuous run mode.
        err = PwrSnsrLib32.PwrSnsr_SetInitiateContinuous(m_handle, 1)
        Utilities.ThrowifError(err)
        'Get the maximum timebase allowed on this meter.
        Dim max As Single
        err = PwrSnsrLib32.PwrSnsr_GetMaxTimebase(m_handle, max)
        Utilities.ThrowifError(err)
        'Construct max label.
        Dim maxLabel As String = Utilities.GetLabelFromTimebase(max)
        'Find the index of the max timebase
        Dim index As Integer = Array.IndexOf(Utilities.TimebaseLabels, maxLabel)
        'Clear the old values, if any.
        comboBox2.Items.Clear()
        'Add the relevant timebase labels.
        For i As Integer = 0 To index
            comboBox2.Items.Add(Utilities.TimebaseLabels(i))
        Next
        'Get the current timebase and label.
        Dim tb As Single
        err = PwrSnsrLib32.PwrSnsr_GetTimebase(m_handle, tb)
        Utilities.ThrowifError(err)
        Dim currentTimebase As String = Utilities.GetLabelFromTimebase(tb)
        'Set the selected item to the current timebase.
        comboBox2.SelectedItem = currentTimebase
        Dim chan As String = "CH1"
        'Set the bandwitch button state.
        Dim bw As PwrSnsrBandwidthEnum = PwrSnsrBandwidthEnum.BandwidthHigh
        err = PwrSnsrLib32.PwrSnsr_GetBandwidth(m_handle, chan, bw)
        Utilities.ThrowifError(err)
        CheckBox2.Checked = (bw = PwrSnsrBandwidthEnum.BandwidthLow)
        'Set averaging to 8.
        comboBox3.SelectedIndex = 3
    End Sub

    Private Sub button3_Click(sender As Object, e As EventArgs) Handles button3.Click
        Try

            'Open meter if closed or vice versa.
            If Not MeterOpen Then
                'Open the session.
                OpenMeter()
                button3.Text = "Close"
                'Set for continuous capturing by checking the checkbox.
                CheckBox1.Checked = True
            Else
                'Close meter.
                Dim err As Integer = PwrSnsrLib32.PwrSnsr_close(m_handle)
                Utilities.ThrowifError(err)
                button3.Text = "Open"
            End If
            MeterOpen = Not MeterOpen
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)

        End Try

    End Sub

    Private Sub CheckBox3_CheckedChanged(sender As Object, e As EventArgs) Handles CheckBox2.CheckedChanged
        Try
            'Select the bandwidth.
            Dim bw As PwrSnsrBandwidthEnum
            If CheckBox2.Checked Then
                bw = PwrSnsrBandwidthEnum.BandwidthLow
                CheckBox2.Text = "Low"
            Else
                bw = PwrSnsrBandwidthEnum.BandwidthHigh
                CheckBox2.Text = "High"
            End If
            'Set the bandwidth.
            Dim err As Integer = PwrSnsrLib32.PwrSnsr_SetBandwidth(m_handle, "CH1", bw)
            Utilities.ThrowifError(err)
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    Private Sub comboBox3_SelectedIndexChanged(sender As Object, e As EventArgs) Handles comboBox3.SelectedIndexChanged
        Try

            Dim avg = Int32.Parse(comboBox3.Text)
            Dim err As Integer = PwrSnsrLib32.PwrSnsr_SetAverage(m_handle, "CH1", avg)
            Utilities.ThrowifError(err)
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    Private Sub button4_Click(sender As Object, e As EventArgs) Handles button4.Click
        Try
            Dim err As Integer = PwrSnsrLib32.PwrSnsr_Clear(m_handle)
            Utilities.ThrowifError(err)
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub
    Private Enum AutoMeasParameter
        Width
        Rise
        Fall
        Period
        PRF
        Duty
        Offtime
        WavAv
        PulsAv
        PulsPk
        OvrSht
        Droop
        Top
        Bottom
        EdgDly
        Skew
    End Enum
    Private Sub PopulateMeasGrid()
        For Each Row As DataGridViewRow In DataGridView1.Rows
            Try
                Row.Cells(2).Value = ""
                If Row.Cells(0).Value = True Then
                    Dim name = Row.Cells(1).Value.ToString()
                    Dim param As AutoMeasParameter = [Enum].Parse(GetType(AutoMeasParameter), name, True)
                    Dim val = GetMeasurement(param)
                    Row.Cells(2).Value = val
                    If Single.IsNaN(val) Then
                        Row.Cells(2).Style.ForeColor = Color.Red
                    ElseIf Single.IsInfinity(val) Then
                        Row.Cells(2).Style.ForeColor = Color.Yellow
                    Else
                        Row.Cells(2).Style.ForeColor = Color.Green

                    End If
                End If
            Catch ex As Exception

            End Try
        Next
    End Sub
    Private Function GetMeasurement(parameter As AutoMeasParameter) As Single
        Dim returnVal As Single = 0.0F
        Dim condCode As PwrSnsrCondCodeEnum = PwrSnsrCondCodeEnum.CondCodeNormal
        Dim err As Integer
        Dim chan = "CH1"


        Select Case parameter
            Case AutoMeasParameter.Width
                err = PwrSnsrLib32.PwrSnsr_FetchWidth(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Rise
                err = PwrSnsrLib32.PwrSnsr_FetchRiseTime(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Fall
                err = PwrSnsrLib32.PwrSnsr_FetchFallTime(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Period
                err = PwrSnsrLib32.PwrSnsr_FetchPeriod(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.PRF
                err = PwrSnsrLib32.PwrSnsr_FetchPRF(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Duty
                err = PwrSnsrLib32.PwrSnsr_FetchDutyCycle(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Offtime
                err = PwrSnsrLib32.PwrSnsr_FetchOfftime(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.WavAv
                err = PwrSnsrLib32.PwrSnsr_FetchPulseCycleAvg(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.PulsAv
                err = PwrSnsrLib32.PwrSnsr_FetchPulseOnAverage(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.PulsPk
                err = PwrSnsrLib32.PwrSnsr_FetchPulsePeak(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.OvrSht
                err = PwrSnsrLib32.PwrSnsr_FetchOvershoot(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Droop
                Dim OvershootValid As PwrSnsrCondCodeEnum
                Dim Overshoot As Single
                Dim IEEEBottomValid As PwrSnsrCondCodeEnum
                Dim IEEEBottom As Single
                Dim IEEETopValid As PwrSnsrCondCodeEnum
                Dim IEEETop As Single
                Dim PulseOnAvgValid As PwrSnsrCondCodeEnum
                Dim PulseOnAvg As Single
                Dim PulsePeakValid As PwrSnsrCondCodeEnum
                Dim PulsePeak As Single
                Dim PulseCycleAvgValid As PwrSnsrCondCodeEnum
                Dim PulseCycleAvg As Single
                Dim Droop As Single
                Dim DroopValid As PwrSnsrCondCodeEnum
                'Get the entire array to so we can return Droop
                err = PwrSnsrLib32.PwrSnsr_FetchPowerArray(
                    m_handle, chan,
                    PulsePeak, PulsePeakValid,
                    PulseCycleAvg, PulseCycleAvgValid,
                    PulseOnAvg, PulseOnAvgValid,
                    IEEETop, IEEETopValid,
                    IEEEBottom, IEEEBottomValid,
                    Overshoot, OvershootValid,
                    Droop, DroopValid
                )
                returnVal = Droop
                condCode = DroopValid

            Case AutoMeasParameter.Top
                err = PwrSnsrLib32.PwrSnsr_FetchIEEETop(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Bottom
                err = PwrSnsrLib32.PwrSnsr_FetchIEEEBottom(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.EdgDly
                err = PwrSnsrLib32.PwrSnsr_FetchEdgeDelay(m_handle, chan, condCode, returnVal)
            Case AutoMeasParameter.Skew
                Dim Frequency As Single
                Dim FrequencyValid As PwrSnsrCondCodeEnum

                Dim Period As Single
                Dim PeriodValid As PwrSnsrCondCodeEnum
                Dim PulseWidth As Single
                Dim PulseWidthValid As PwrSnsrCondCodeEnum
                Dim Offtime As Single
                Dim OfftimeValid As PwrSnsrCondCodeEnum
                Dim DutyCycle As Single
                Dim DutyCycleValid As PwrSnsrCondCodeEnum
                Dim Risetime As Single
                Dim RisetimeValid As PwrSnsrCondCodeEnum
                Dim Falltime As Single
                Dim FalltimeValid As PwrSnsrCondCodeEnum
                Dim EdgeDelay As Single
                Dim EdgeDelayValid As PwrSnsrCondCodeEnum
                Dim Skew As Single
                Dim SkewValid As PwrSnsrCondCodeEnum
                err = PwrSnsrLib32.PwrSnsr_FetchTimeArray(m_handle, chan,
                    Frequency, FrequencyValid, Period, PeriodValid, PulseWidth,
                     PulseWidthValid, Offtime, OfftimeValid, DutyCycle, DutyCycleValid, Risetime,
                     RisetimeValid, Falltime, FalltimeValid, EdgeDelay, EdgeDelayValid, Skew,
                     SkewValid)
                returnVal = Skew
                condCode = SkewValid
        End Select
        'Throw error if needed
        Utilities.ThrowifError(err)
        If (condCode = PwrSnsrCondCodeEnum.CondCodeError) Then
            returnVal = Single.NaN
        End If

        If (condCode = PwrSnsrCondCodeEnum.CondCodeOverrange) Then
            returnVal = Single.PositiveInfinity
        End If

        If (condCode = PwrSnsrCondCodeEnum.CondCodeUnderrange) Then
            returnVal = Single.NegativeInfinity
        End If


        Return returnVal
    End Function

    Private Sub Timer1_Tick(sender As Object, e As EventArgs) Handles Timer1.Tick
        Try
            PopulateMeasGrid()
        Catch ex As Exception

        End Try
    End Sub

    Private Sub CheckBox1_CheckedChanged(sender As Object, e As EventArgs) Handles CheckBox1.CheckedChanged
        Timer1.Enabled = CheckBox1.Checked
    End Sub

    Private Sub DataGridView1_RowsAdded(sender As Object, e As DataGridViewRowsAddedEventArgs) Handles DataGridView1.RowsAdded


    End Sub

    Private Sub DataGridView1_CellContentClick(sender As Object, e As DataGridViewCellEventArgs) Handles DataGridView1.CellContentClick
        If (e.ColumnIndex = 3) Then
            Try
                Dim Row = DataGridView1.Rows(e.RowIndex)
                Dim name = Row.Cells(1).Value.ToString()
                Dim param As AutoMeasParameter = [Enum].Parse(GetType(AutoMeasParameter), name, True)
                Dim val = GetMeasurement(param)
                Row.Cells(2).Value = val
                If Single.IsNaN(val) Then
                    Row.Cells(2).Style.ForeColor = Color.Red
                ElseIf Single.IsInfinity(val) Then
                    Row.Cells(2).Style.ForeColor = Color.Yellow
                Else
                    Row.Cells(2).Style.ForeColor = Color.Green

                End If
            Catch ex As Exception

            End Try
        End If
    End Sub

    Private Sub DataGridView1_CellValueChanged(sender As Object, e As DataGridViewCellEventArgs) Handles DataGridView1.CellValueChanged
        If (e.ColumnIndex = 1) Then
            Try
                DataGridView1.Rows(e.RowIndex).Cells(0).Value = True

            Catch ex As Exception

            End Try
        End If

    End Sub

    Private Sub DataGridView1_CellEndEdit(sender As Object, e As DataGridViewCellEventArgs) Handles DataGridView1.CellEndEdit
        Try
            DataGridView1.Rows(e.RowIndex).Selected = False

        Catch ex As Exception

        End Try
    End Sub

    Private Sub comboBox2_SelectedIndexChanged(sender As Object, e As EventArgs) Handles comboBox2.SelectedIndexChanged
        Try
            If Not String.IsNullOrEmpty(comboBox2.Text) Then
                'Parse the current text in the combobox and set the meter's timebase.
                Dim tb As Single = CSng(Utilities.GetTimebaseFromLabel(comboBox2.Text))
                Dim err As Integer
                err = PwrSnsrLib32.PwrSnsr_SetTimebase(m_handle, tb)
            End If
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.[Error])
        End Try
    End Sub
End Class
