﻿
'***************************** Module Header ******************************\
'Module Name:  Utilities
'Project:      BoontonautoMeasExample
'Copyright (c) 2014 Boonton
'
'Utility class for numeric formating.
'
'
'THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
'EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
'WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
'\**************************************************************************

Imports System.Collections.Generic
Imports System.Linq
Imports System.Text
Imports PowerMeterManagement

Class Utilities
    Shared m_TimebaseLabels As String()

    Public Shared Property TimebaseLabels() As String()
        Get
            Return Utilities.m_TimebaseLabels
        End Get
        Private Set(value As String())
            Utilities.m_TimebaseLabels = value
        End Set
    End Property


    Shared m_TimebaseMultipliers As Double() = {0.000000001, 0.000000001, 0.000000001, 0.000000001, 0.000000001, 0.000000001, _
        0.000000001, 0.000001, 0.000001, 0.000001, 0.000001, 0.000001, _
        0.000001, 0.000001, 0.000001, 0.000001, 0.001, 0.001, _
        0.001, 0.001, 0.001, 0.001, 0.001, 0.001, _
        0.001, 1.0, 1.0, 1.0, 1.0, 1.0, _
        1.0, 1.0, 1.0, 1.0, 1.0, 1.0}

    Shared m_TimeBases As Double() = {0.000000005, 0.00000001, 0.00000002, 0.00000005, 0.0000001, 0.0000002, _
        0.0000005, 0.000001, 0.000002, 0.000005, 0.00001, 0.00002, _
        0.00005, 0.0001, 0.0002, 0.0005, 0.001, 0.002, _
        0.005, 0.01, 0.02, 0.05, 0.1, 0.2, _
        0.5, 1.0, 2.0, 5.0, 10.0, 30.0, _
        60.0, 120.0, 300.0, 600.0, 1800.0, 3600.0}

    Shared m_TimebaseTable As New Dictionary(Of String, Double)()
    Shared m_TimebaseMultTable As New Dictionary(Of String, Double)()
    Shared Sub New()
        m_TimebaseLabels = New String(m_TimeBases.Length - 1) {}
        For i As Integer = 0 To m_TimeBases.Length - 1
            Dim val As Double = m_TimeBases(i)
            If val > 1.0 Then
                m_TimebaseLabels(i) = ToEngineeringNotation(val, "# ", 0) & Convert.ToString("s/div")
            Else
                m_TimebaseLabels(i) = ToEngineeringNotation(val, "# ") & Convert.ToString("s/div")
            End If
            m_TimebaseTable.Add(m_TimebaseLabels(i), val)
            m_TimebaseMultTable.Add(m_TimebaseLabels(i), m_TimebaseMultipliers(i))





        Next
    End Sub
    Protected Shared m_errorMap As Dictionary(Of Integer, String) = New Dictionary(Of Integer, String)() From {
    {CInt(PwrSnsrErrorCodesEnum.IO_GENERAL), "I/O Error."},
    {CInt(PwrSnsrErrorCodesEnum.IO_TIMEOUT), "Timeout."},
    {CInt(PwrSnsrErrorCodesEnum.MODEL_NOT_SUPPORTED), "Sensor model not supported."},
    {CInt(PwrSnsrErrorCodesEnum.INV_PARAMETER), "Invalid parameter."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_INVALID_SESSION_HANDLE), "Invalid session ID."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_STATUS_NOT_AVAILABLE), "Status not available."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_RESET_FAILED), "Reset failed."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_RESOURCE_UNKNOWN), "Unknown resource."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_ALREADY_INITIALIZED), "Session already initialized"},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_OUT_OF_MEMORY), ""},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_OPERATION_PENDING), "Operation pending."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_NULL_POINTER), "Null pointer error."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_UNEXPECTED_RESPONSE), "Unexpected response."},
    {CInt(PwrSnsrErrorCodesEnum.ERROR_NOT_INITIALIZED), "Session not initialized."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_IO), "I/O error."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_INVALID_PARAM), "Invalid parameter"},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_ACCESS), "Access violation."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NO_DEVICE), "USB device lost."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NOT_FOUND), "USB device not found."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_BUSY), "USB busy."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_TIMEOUT), "Timeout error"},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_OVERFLOW), "Overflow error."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_PIPE), "USB pipe error."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_INTERRUPTED), "Interrupted communication."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NO_MEM), "No memory available."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_NOT_SUPPORTED), "Sensor not supported."},
    {CInt(PwrSnsrErrorCodesEnum.LIBUSB_ERROR_OTHER), "Unknown error"}
}
    Public Shared Function DecodeAscii(ByVal buffer As Byte()) As String
        Dim count As Integer = Array.IndexOf(Of Byte)(buffer, 0, 0)
        If count < 0 Then count = buffer.Length
        Return Encoding.ASCII.GetString(buffer, 0, count)
    End Function
    Public Shared Function MapError(ByVal err As Integer) As String
        Dim retval As String = "Unknown error"
        m_errorMap.TryGetValue(err, retval)
        Return If(retval, "Unknown error")
    End Function
    Public Shared Sub ThrowifError(ByVal result As Integer)
        If result <> PwrSnsrLib32.SUCCESS Then
            Dim msg = MapError(result)
            Throw New SensorIOException(msg)
        End If
    End Sub
    Public Class SensorIOException
        Inherits Exception

        Public Sub New(ByVal message As String)
            MyBase.New(message)
        End Sub
    End Class

    Public Shared Function GetLabelFromTimebase(timebase As Double) As String
        Dim ret = m_TimebaseTable.Where(Function(x) x.Value / timebase > 0.99 AndAlso x.Value / timebase < 1.01).[Select](Function(x) x.Key)
        If ret.Count() > 0 Then
            Return ret.ElementAt(0)
        End If
        Return Nothing
    End Function

    Public Shared Function GetTimebaseFromLabel(label As String) As Double
        Return m_TimebaseTable(label)
    End Function

    ''' <summary>
    ''' Converts a double to its Engineering format representation
    ''' </summary>
    ''' <param name="d">Double to convert.</param>
    ''' <param name="numberFormat">Number format to use eg. "#.000"</param>
    ''' <returns></returns>
    ''' 
    Public Shared Function ToEngineeringNotation(d As Double, numberFormat As String) As String
        Return ToEngineeringNotation(d, numberFormat, 0, False)
    End Function

    Public Shared Function ToEngineeringNotation(d As Double, significantDigits As Integer, Optional minExp As Integer = -9) As String
        Return ToEngineeringNotation(d, "", 0, False, True, significantDigits, _
            minExp)
    End Function

    ''' <summary>
    ''' Converts a double to its Engineering format representation
    ''' </summary>
    ''' <param name="d">Double to convert.</param>
    ''' <param name="numberFormat">Number format to use eg. "#.000"</param>
    ''' <param name="exponent">Specified exponent units.</param>
    ''' <returns></returns>
    ''' 
    Public Shared Function ToEngineeringNotation(d As Double, numberFormat As String, exponent As Integer) As String
        Return ToEngineeringNotation(d, numberFormat, exponent, True)
    End Function


    Private Shared Function ToEngineeringNotation(d As Double, numberFormat As String, exponent As Integer, forceExponent As Boolean, Optional useSigDigs As Boolean = False, Optional sigDigs As Integer = 5, _
        Optional minExp As Integer = -9) As String
        'd = Math.Round(d, 12);
        If Not forceExponent Then
            exponent = CInt(Math.Floor(Math.Log10(Math.Abs(d))))
        End If


        If exponent < minExp Then
            exponent = minExp
        End If

        Dim scaledVal As Double = 0.0

        If exponent >= 0 Then
            Select Case exponent
                Case 0, 1, 2
                    scaledVal = d
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " "
                Case 3, 4, 5
                    scaledVal = (d / 1000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " k"
                Case 6, 7, 8
                    scaledVal = (d / 1000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " M"
                Case 9, 10, 11
                    scaledVal = (d / 1000000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " G"
                Case 12, 13, 14
                    scaledVal = (d / 1000000000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " T"
                Case 15, 16, 17
                    scaledVal = (d / 1.0E+15)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " P"
                Case 18, 19, 20
                    scaledVal = (d / 1.0E+18)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " E"
                Case 21, 22, 23
                    scaledVal = (d / 1.0E+21)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " Z"
                Case Else
                    scaledVal = (d / 1.0E+24)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " Y"
            End Select
        ElseIf exponent < 0 Then
            Select Case exponent
                Case 0
                    scaledVal = d
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " "
                Case -1, -2, -3
                    scaledVal = (d * 1000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " m"
                Case -4, -5, -6
                    scaledVal = (d * 1000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " μ"
                Case -7, -8, -9
                    scaledVal = (d * 1000000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " n"
                Case -10, -11, -12
                    scaledVal = (d * 1000000000000.0)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " p"
                Case -13, -14, -15
                    scaledVal = (d * 1.0E+15)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " f"
                Case -16, -17, -18
                    scaledVal = (d * 1.0E+15)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " a"
                Case -19, -20, -21
                    scaledVal = (d * 1.0E+15)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " z"
                Case Else
                    scaledVal = (d * 1.0E+15)
                    If useSigDigs Then
                        numberFormat = GetSigDigFormat(scaledVal, sigDigs)
                    End If
                    Return scaledVal.ToString(numberFormat) + " y"
            End Select
        Else
            If useSigDigs Then
                numberFormat = GetSigDigFormat(d, sigDigs)
            End If
            Return d.ToString(numberFormat) + " "
        End If
    End Function
    Private Shared Function GetSigDigFormat(number As Double, numberDigits As Integer) As String
        Dim exponent As Integer = 0
        If number <> 0.0 Then

            exponent = CInt(Math.Floor(Math.Log10(Math.Abs(number))))
        End If
        Dim format As String = "#0"
        Dim rightPlaces As Integer = numberDigits - exponent - 1

        For i As Integer = 0 To rightPlaces - 1
            If i = 0 Then
                format += ".0"
            Else
                format += "0"
            End If
        Next
        Return format
    End Function


End Class


